/**
 * abssqr.com Inc. 
 * Copyright (c) 2017-2018 All Rights Reserved. 
 */
package com.abssqr.plat.biz.interceptor;

import com.abssqr.plat.common.facade.base.BaseParam;
import com.abssqr.plat.common.facade.enums.EventCodeEnum;
import com.abssqr.plat.common.model.exception.AbssqrInvalidParamException;
import com.general.system.common.model.BaseResult;
import com.general.system.common.model.IErrorCode;
import com.general.system.common.model.exception.BaseException;
import com.general.system.common.util.LogUtil;
import org.aopalliance.intercept.MethodInvocation;
import org.slf4j.Logger;

/**
 *
 * @author zhenxuan.luo
 * @version com.loan.biz.service.inteceptor: InterceptorUtil.java, v 0.1 2018-12-19 PM12:20 zhenxuan.luo Exp $ 
 */
public class InterceptorUtil {
    
    /**
     * 私有构造函数
     */
    private InterceptorUtil() {
    }
    
    /**
     * 处理错误，打日志并生成facade的返回结果
     *
     * @param logger logger
     * @param invocation 接口调用
     * @param message 错误消息
     * @param errorCodeEnum 错误码
     * @param e 错误
     * @return facade的返回结果
     */
    public static Object processError(Logger logger, MethodInvocation invocation, String message,
                                      IErrorCode errorCodeEnum, BaseException e)
            throws IllegalAccessException, InstantiationException {
        LogUtil.error(logger, e, message);
        
        // 构造结果
        Class<?> returnType = invocation.getMethod().getReturnType();
        if (BaseResult.class.isAssignableFrom(returnType)) {
            
            // 资产交换一阶段处理结果
            BaseResult<?> result = (BaseResult<?>) returnType.newInstance();
            result.setSuccess(false);
            result.setErrorMessage(message);
            result.setErrorCode(String.valueOf(errorCodeEnum.getCode()));
            if (null != e) {
                result.setNeedRetry(e.isCanRetry());
            }
            return result;
        }
        throw new AbssqrInvalidParamException(message);
//        return null;
    }
    
    /**
     * 获取一次接口调用的事件码编码
     *
     * @param invocation 接口调用
     * @return 事件码编码, 获取不到时返回EventCodeEnum.UNKNOWN
     */
    public static String getEventCode(MethodInvocation invocation) {
        EventCodeEnum eventCode = getEventCodeEnum(invocation);
        return eventCode == null ? EventCodeEnum.OTHER.getCode() : eventCode.getCode();
    }
    
    /**
     * 获取一次接口调用的事件码枚举
     *
     * @param invocation 接口调用
     * @return 事件码
     */
    private static EventCodeEnum getEventCodeEnum(MethodInvocation invocation) {
        
        Object[] args = invocation.getArguments();
        if (args == null) {
            return null;
        }
        for (Object arg : args) {
            if (arg instanceof BaseParam) {
                return ((BaseParam) arg).getEventCode();
            }
        }
        return EventCodeEnum.OTHER;
    }
    
}