/**
 * abssqr.com Inc.
 * Copyright (c) 2017-2017 All Rights Reserved.
 */
package com.abssqr.plat.biz.validate.validator;

import com.abssqr.plat.biz.validate.AFieldValidator;
import com.abssqr.plat.biz.validate.FieldError;
import com.abssqr.plat.biz.validate.ValidateService;
import com.abssqr.plat.biz.validate.ValidatorError;
import com.abssqr.plat.common.facade.validation.VldCollection;

import java.util.Collection;

/**
 * 注解@{@link VldCollection}的校验类实现
 * @author zhenxuan.luo
 * @version $Id: CollectionValidator.java, v 0.1 2015年5月19日 上午10:54:34 zhenxuan.luo Exp $
 */
public final class CollectionValidator extends AFieldValidator<VldCollection> {
    /**
     * 默认构造器
     */
    public CollectionValidator() {
        super(VldCollection.class);
    }
    
    @Override
    public boolean isValid(ValidateService validateService, VldCollection annotationObj,
                           Object validTargetFieldObj, FieldError errorConext) {
        boolean isValid = false;
        try {
            return isValid = validate(validateService, annotationObj, validTargetFieldObj,
                    errorConext);
        } finally {
            if (!isValid) {
                errorConext.setErrorMsg(errorConext.getErrorMsg() + annotationObj.message());
            }
        }
    }
    
    /**
     * 校验
     * @param validateService 对象校验器
     * @param annotationObj 校验注解对象
     * @param validTargetFieldObj 需要校验的字段对象
     * @param errorConext 每个字段错误的存储类
     * @return true:校验通过,反之返回false
     */
    private boolean validate(ValidateService validateService, VldCollection annotationObj,
                             Object validTargetFieldObj, FieldError errorConext) {
        if (validTargetFieldObj == null) {
            return (annotationObj.nullable()) ? true : false;
        }
        int minSize = annotationObj.minSize();
        int maxSize = annotationObj.maxSize();
        if (validTargetFieldObj instanceof Collection) {
            Collection<?> c = (Collection<?>) validTargetFieldObj;
            int size = c.size();
            boolean isValid = (size >= minSize) && (size <= maxSize);
            // 如果不做嵌套校验，则直接返回结果
            if (!annotationObj.nestable()) {
                return isValid;
            } else if (isValid) {
                //嵌套校验
                for (Object nestTargetObj : c) {
                    ValidatorError ve = validateService.validate(nestTargetObj);
                    //嵌套校验,发现一个出错就直接退出,不校验后续
                    if (ve.hasErrors()) {
                        StringBuilder sb = ve.getErrorMsg("<[cause by:", "]>");
                        errorConext.setErrorMsg(sb.toString());
                        return false;
                    }
                }
                return true;
            }
        }
        return false;
    }
}
