package com.abssqr.plat.common.dal.mysql.auto.dao;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Repository;
import java.util.ArrayList;
import com.abssqr.plat.common.dal.mysql.auto.dataobject.LoanDO;
import com.abssqr.plat.common.dal.mysql.auto.paging.LoanListPage;
import com.abssqr.plat.common.dal.mysql.auto.resultmap.LoanPropCntStat;
import com.abssqr.plat.common.dal.mysql.auto.paging.CapitalAstMatchPage;
import com.abssqr.plat.common.dal.mysql.auto.paging.CapitalAstUnMatchPage;
import com.abssqr.plat.common.dal.mysql.auto.resultmap.AstPoolLoanStat;
import com.abssqr.plat.common.dal.mysql.auto.paging.AstPoolLoanPagePage;
import com.abssqr.plat.common.dal.mysql.auto.mapper.LoanDOMapper;

/**
* The Table abs_loan.
* 信贷资产
*/
@Repository
public class LoanDAO{

    @Autowired
    private LoanDOMapper loanDOMapper;

    /**
     * desc:插入表:abs_loan.<br/>
     * @param entity entity
     * @return int
     */
    
    public int insert(LoanDO entity){
        return loanDOMapper.insert(entity);
    }
    /**
     * desc:根据唯一约束OutAstNo更新表:abs_loan.<br/>
     * @param entity entity
     * @return int
     */
    
    public int updateByAstNo(LoanDO entity){
        return loanDOMapper.updateByAstNo(entity);
    }
    /**
     * desc:根据唯一约束OutAstNo获取数据:abs_loan.<br/>
     * @param outAstNo outAstNo
     * @param managerOrgCode managerOrgCode
     * @return LoanDO
     */
    
    public LoanDO getByOutAstNo(String outAstNo,String managerOrgCode){
        return loanDOMapper.getByOutAstNo(outAstNo, managerOrgCode);
    }
    /**
     * desc:根据唯一约束OutAstNo获取数据:abs_loan.<br/>
     * @param outAstNo outAstNo
     * @param managerOrgCode managerOrgCode
     * @return LoanDO
     */
    
    public LoanDO lockByOutAstNo(String outAstNo,String managerOrgCode){
        return loanDOMapper.lockByOutAstNo(outAstNo, managerOrgCode);
    }
    /**
     * desc:根据唯一约束AbsLoan获取数据:abs_loan.<br/>
     * @param astNo astNo
     * @return LoanDO
     */
    
    public LoanDO getByAstNo(String astNo){
        return loanDOMapper.getByAstNo(astNo);
    }
    /**
     * desc:根据唯一约束AbsLoan获取数据:abs_loan.<br/>
     * @param astNo astNo
     * @return LoanDO
     */
    
    public LoanDO lockByAstNo(String astNo){
        return loanDOMapper.lockByAstNo(astNo);
    }
    /**
     * desc:getPageByOwnOrg.<br/>
     * @param loanList loanList
     * @return LoanListPage
     */
    
    public LoanListPage getPageByOwnOrg(LoanListPage loanList){
        int total = loanDOMapper.getPageByOwnOrgCount(loanList);
        if(total>0){
            loanList.setDatas(loanDOMapper.getPageByOwnOrgResult(loanList));
        }else{
            loanList.setDatas(new ArrayList());
        }
        loanList.setTotal(total);
        return loanList;
    }
    /**
     * desc:统计机构当前资产规模.<br/>
     * @param lenderOrgCode lenderOrgCode
     * @return LoanPropCntStat
     */
    
    public LoanPropCntStat statPlanBal(String lenderOrgCode){
        return loanDOMapper.statPlanBal(lenderOrgCode);
    }
    /**
     * desc:统计放款池当前持有资产规模(不包含已转出).<br/>
     * @param lenderOrgCode lenderOrgCode
     * @return LoanPropCntStat
     */
    
    public LoanPropCntStat statSpvBal(String lenderOrgCode){
        return loanDOMapper.statSpvBal(lenderOrgCode);
    }
    /**
     * desc:资金资产匹配分页.<br/>
     * @param capitalAstMatch capitalAstMatch
     * @return CapitalAstMatchPage
     */
    
    public CapitalAstMatchPage queryForCapitalAstMatch(CapitalAstMatchPage capitalAstMatch){
        int total = loanDOMapper.queryForCapitalAstMatchCount(capitalAstMatch);
        if(total>0){
            capitalAstMatch.setDatas(loanDOMapper.queryForCapitalAstMatchResult(capitalAstMatch));
        }else{
            capitalAstMatch.setDatas(new ArrayList());
        }
        capitalAstMatch.setTotal(total);
        return capitalAstMatch;
    }
    /**
     * desc:资金资产解绑分页.<br/>
     * @param capitalAstUnMatch capitalAstUnMatch
     * @return CapitalAstUnMatchPage
     */
    
    public CapitalAstUnMatchPage queryForCapitalAstUnMatch(CapitalAstUnMatchPage capitalAstUnMatch){
        int total = loanDOMapper.queryForCapitalAstUnMatchCount(capitalAstUnMatch);
        if(total>0){
            capitalAstUnMatch.setDatas(loanDOMapper.queryForCapitalAstUnMatchResult(capitalAstUnMatch));
        }else{
            capitalAstUnMatch.setDatas(new ArrayList());
        }
        capitalAstUnMatch.setTotal(total);
        return capitalAstUnMatch;
    }
    /**
     * desc:根据资产池编号统计已打包为总共的本金余额和资产笔数.<br/>
     * @param astPoolNo astPoolNo
     * @return AstPoolLoanStat
     */
    
    public AstPoolLoanStat statPrinAndCnt(String astPoolNo){
        return loanDOMapper.statPrinAndCnt(astPoolNo);
    }
    /**
     * desc:根据资产池编号查询对应的资产.<br/>
     * @param astPoolLoanPage astPoolLoanPage
     * @return AstPoolLoanPagePage
     */
    
    public AstPoolLoanPagePage getLoanListByAstPoolNo(AstPoolLoanPagePage astPoolLoanPage){
        int total = loanDOMapper.getLoanListByAstPoolNoCount(astPoolLoanPage);
        if(total>0){
            astPoolLoanPage.setDatas(loanDOMapper.getLoanListByAstPoolNoResult(astPoolLoanPage));
        }else{
            astPoolLoanPage.setDatas(new ArrayList());
        }
        astPoolLoanPage.setTotal(total);
        return astPoolLoanPage;
    }
}
