package com.abssqr.plat.common.dal.mysql.auto.mapper;

import com.abssqr.plat.common.dal.mysql.auto.dataobject.LoanBakDO;
import java.util.List;
import java.util.Date;
import com.abssqr.plat.common.dal.mysql.auto.resultmap.PropDisbStat;
import com.abssqr.plat.common.dal.mysql.auto.resultmap.PropCntStat;
import com.abssqr.plat.common.dal.mysql.auto.paging.LoanBakListPage;
import com.abssqr.plat.common.dal.mysql.auto.resultmap.LoanBakFormationItem;
import com.abssqr.plat.common.dal.mysql.auto.resultmap.LoanBakReportStat;
import com.abssqr.plat.common.dal.mysql.auto.resultmap.AstScale;
import org.apache.ibatis.annotations.Param;

/**
 * 由于需要对分页支持,请直接使用对应的DAO类
 * The Table abs_loan_bak.
 * 信贷资产
 */
public interface LoanBakDOMapper{

    /**
     * desc:批量插入表:abs_loan_bak.<br/>
     * @param list list
     * @return int
     */
    int insertBatch(List<LoanBakDO> list);
    /**
     * desc:根据主键获取数据:abs_loan_instal_log.<br/>
     * @param accountDate accountDate
     * @param planNo planNo
     * @return PropDisbStat
     */
    PropDisbStat statDisb(@Param("accountDate")Date accountDate,@Param("planNo")String planNo);
    /**
     * desc:statPlanBal.<br/>
     * @param accountDate accountDate
     * @param ownOrg ownOrg
     * @return PropCntStat
     */
    PropCntStat statPlanBal(@Param("accountDate")Date accountDate,@Param("ownOrg")String ownOrg);
    /**
     * desc:根据主键获取数据:abs_loan_instal_log.<br/>
     * @param accountDate accountDate
     * @param planNo planNo
     * @return List<PropCntStat>
     */
    List<PropCntStat> statLocation(@Param("accountDate")Date accountDate,@Param("planNo")String planNo);
    /**
     * desc:根据主键获取数据:ABS_LOAN_BAK.<br/>
     * @param accountDate accountDate
     * @param planNo planNo
     * @return List<PropCntStat>
     */
    List<PropCntStat> statAge(@Param("accountDate")Date accountDate,@Param("planNo")String planNo);
    /**
     * desc:根据主键获取数据:ABS_LOAN_BAK.<br/>
     * @param accountDate accountDate
     * @param planNo planNo
     * @return List<PropCntStat>
     */
    List<PropCntStat> statGender(@Param("accountDate")Date accountDate,@Param("planNo")String planNo);
    /**
     * desc:getPageByOwnOrgCount.<br/>
     * @param loanBakList loanBakList
     * @return int
     */
    int getPageByOwnOrgCount(LoanBakListPage loanBakList);
    /**
     * desc:getPageByOwnOrgResult.<br/>
     * @param loanBakList loanBakList
     * @return List<LoanBakDO>
     */
    List<LoanBakDO> getPageByOwnOrgResult(LoanBakListPage loanBakList);
    /**
     * desc:统计资产当前剩余分期数量及余额总计.<br/>
     * @param accountDate accountDate
     * @param ownOrg ownOrg
     * @return List<LoanBakFormationItem>
     */
    List<LoanBakFormationItem> queryAstFormation(@Param("accountDate")Date accountDate,@Param("ownOrg")String ownOrg);
    /**
     * desc:统计资产产品分期及余额总计.<br/>
     * @param accountDate accountDate
     * @param ownOrg ownOrg
     * @return List<LoanBakFormationItem>
     */
    List<LoanBakFormationItem> queryProdFormation(@Param("accountDate")Date accountDate,@Param("ownOrg")String ownOrg);
    /**
     * desc:资产余额状态统计代替statBal.<br/>
     * @param accountDate accountDate
     * @param planNo planNo
     * @return List<LoanBakReportStat>
     */
    List<LoanBakReportStat> statLoanBakStatus(@Param("accountDate")Date accountDate,@Param("planNo")String planNo);
    /**
     * desc:五级分类统计代替statBal.<br/>
     * @param accountDate accountDate
     * @param planNo planNo
     * @return List<LoanBakReportStat>
     */
    List<LoanBakReportStat> statLoanBakClz(@Param("accountDate")Date accountDate,@Param("planNo")String planNo);
    /**
     * desc:91逾期未核销统计代替statBal.<br/>
     * @param accountDate accountDate
     * @param planNo planNo
     * @param statVal statVal
     * @param statType statType
     * @param wtfStatus wtfStatus
     * @param ovdDays ovdDays
     * @return List<LoanBakReportStat>
     */
    List<LoanBakReportStat> statLoanBakOvdWtf(@Param("accountDate")Date accountDate,@Param("planNo")String planNo,@Param("statVal")String statVal,@Param("statType")String statType,@Param("wtfStatus")String wtfStatus,@Param("ovdDays")Integer ovdDays);
    /**
     * desc:ovd_day天数统计代替statBal.<br/>
     * @param accountDate accountDate
     * @param planNo planNo
     * @return List<LoanBakReportStat>
     */
    List<LoanBakReportStat> statLoanBakOvdDays(@Param("accountDate")Date accountDate,@Param("planNo")String planNo);
    /**
     * desc:统计当日新增资产年化收益.<br/>
     * @param inDate inDate
     * @param disbDate disbDate
     * @param accountDate accountDate
     * @param planNo planNo
     * @return List<LoanBakReportStat>
     */
    List<LoanBakReportStat> statLoanBakProfit(@Param("inDate")Date inDate,@Param("disbDate")Date disbDate,@Param("accountDate")Date accountDate,@Param("planNo")String planNo);
    /**
     * desc:获取资产规模.<br/>
     * @param accountDate accountDate
     * @param planNo planNo
     * @return List<AstScale>
     */
    List<AstScale> getAstScale(@Param("accountDate")Date accountDate,@Param("planNo")String planNo);
}
