package com.abssqr.plat.common.dal.mysql.auto.mapper;

import com.abssqr.plat.common.dal.mysql.auto.dataobject.ProductDO;
import java.util.List;
import com.abssqr.plat.common.dal.mysql.auto.paging.ProductListPage;
import org.apache.ibatis.annotations.Param;

/**
 * 由于需要对分页支持,请直接使用对应的DAO类
 * The Table ABS_PRODUCT.
 * ABS_PRODUCT
 */
public interface ProductDOMapper{

    /**
     * desc:插入表:ABS_PRODUCT.<br/>
     * @param entity entity
     * @return int
     */
    int insert(ProductDO entity);
    /**
     * desc:批量插入表:ABS_PRODUCT.<br/>
     * @param list list
     * @return int
     */
    int insertBatch(List<ProductDO> list);
    /**
     * desc:根据唯一约束OrgCodeProdCode获取数据:ABS_PRODUCT.<br/>
     * @param prodCode prodCode
     * @param managerOrgCode managerOrgCode
     * @return ProductDO
     */
    ProductDO getByOrgCodeProdCode(@Param("prodCode")String prodCode,@Param("managerOrgCode")String managerOrgCode);
    /**
     * desc:根据唯一约束AbssqrProdCode删除数据:ABS_PRODUCT.<br/>
     * @param abssqrProdCode abssqrProdCode
     * @return int
     */
    int deleteByAbssqrProdCode(@Param("abssqrProdCode")String abssqrProdCode);
    /**
     * desc:根据唯一约束AbssqrProdCode获取数据:ABS_PRODUCT.<br/>
     * @param abssqrProdCode abssqrProdCode
     * @return ProductDO
     */
    ProductDO getByAbssqrProdCode(@Param("abssqrProdCode")String abssqrProdCode);
    /**
     * desc:根据唯一约束AbssqrProdCode获取数据:ABS_PRODUCT.<br/>
     * @param abssqrProdCodes abssqrProdCodes
     * @return List<ProductDO>
     */
    List<ProductDO> getByAbssqrProdCodes(@Param("abssqrProdCodes")List<String> abssqrProdCodes);
    /**
     * desc:更新产品.<br/>
     * @param entity entity
     * @return int
     */
    int update(ProductDO entity);
    /**
     * desc:获取产品.<br/>
     * @param prodCode prodCode
     * @return ProductDO
     */
    ProductDO getByProdCode(@Param("prodCode")String prodCode);
    /**
     * desc:获取同名产品数量，防止重名存在.<br/>
     * @param entity entity
     * @return Integer
     */
    Integer getSameProdCnt(ProductDO entity);
    /**
     * desc:查询产品列表.<br/>
     * @param productList productList
     * @return int
     */
    int getProductListCount(ProductListPage productList);
    /**
     * desc:查询产品列表.<br/>
     * @param productList productList
     * @return List<ProductDO>
     */
    List<ProductDO> getProductListResult(ProductListPage productList);
}
