package com.abssqr.plat.common.dal.mysql.auto.mapper;

import com.abssqr.plat.common.dal.mysql.auto.dataobject.TaskGroupDO;
import java.util.List;
import com.abssqr.plat.common.dal.mysql.auto.resultmap.HostTaskGroupCnt;
import org.apache.ibatis.annotations.Param;

/**
 * 由于需要对分页支持,请直接使用对应的DAO类
 * The Table abs_task_group.
 * ABS_TASK_GROUP
 */
public interface TaskGroupDOMapper{

    /**
     * desc:插入表:abs_task_group.<br/>
     * @param entity entity
     * @return int
     */
    int insert(TaskGroupDO entity);
    /**
     * desc:批量插入表:abs_task_group.<br/>
     * @param list list
     * @return int
     */
    int insertBatch(List<TaskGroupDO> list);
    /**
     * desc:更新表:abs_task_group.<br/>
     * @param entity entity
     * @return int
     */
    int update(TaskGroupDO entity);
    /**
     * desc:根据主键删除数据:abs_task_group.<br/>
     * @param id id
     * @return int
     */
    int deleteById(@Param("id")Long id);
    /**
     * desc:根据主键获取数据:abs_task_group.<br/>
     * @param id id
     * @return TaskGroupDO
     */
    TaskGroupDO getById(@Param("id")Long id);
    /**
     * desc:获取所有未完成的任务组.<br/>
     * @param jobName jobName
     * @return List<TaskGroupDO>
     */
    List<TaskGroupDO> getAllUnFinishTaskGroupByJobName(@Param("jobName")String jobName);
    /**
     * desc:获取各个主机的正在运行的任务组.<br/>
     * @param jobName jobName
     * @return List<HostTaskGroupCnt>
     */
    List<HostTaskGroupCnt> getHostTaskGroupCnt(@Param("jobName")String jobName);
    /**
     * desc:更改当前任务的状态.<br/>
     * @param id id
     * @param status status
     * @return int
     */
    int updateTaskGroupStatusById(@Param("id")Long id,@Param("status")String status);
    /**
     * desc:根据HOSTIP和Disable状态 数据:abs_task_group.<br/>
     * @param jobName jobName
     * @param hostName hostName
     * @return List<TaskGroupDO>
     */
    List<TaskGroupDO> getExecTaskGroupByHostIpAndJobName(@Param("jobName")String jobName,@Param("hostName")String hostName);
    /**
     * desc:获取所有正在执行的任务区间.<br/>
     * @param jobName jobName
     * @return List<TaskGroupDO>
     */
    List<TaskGroupDO> getAllExecTaskGroupByJobName(@Param("jobName")String jobName);
    /**
     * desc:获取一个可分配的任务区间.<br/>
     * @param jobName jobName
     * @return TaskGroupDO
     */
    TaskGroupDO getAvailableTaskGroupByJobName(@Param("jobName")String jobName);
    /**
     * desc:获取所有已经分配任务区间的机器.<br/>
     * @param jobName jobName
     * @return List<TaskGroupDO>
     */
    List<TaskGroupDO> getAllExeMachine(@Param("jobName")String jobName);
    /**
     * desc:更改当前任务为初始化状态.<br/>
     * @param id id
     * @return int
     */
    int updateTaskGroupInit(@Param("id")Long id);
    /**
     * desc:更改当前任务为Disable=true的状态.<br/>
     * @param id id
     * @param disable disable
     * @param oldDisable oldDisable
     * @return int
     */
    int updateTaskGroupDisable(@Param("id")Long id,@Param("disable")Boolean disable,@Param("oldDisable")Boolean oldDisable);
    /**
     * desc:为机器分配任务.<br/>
     * @param id id
     * @param hostName hostName
     * @return int
     */
    int updateTaskGroupOwner(@Param("id")Long id,@Param("hostName")String hostName);
    /**
     * desc:为机器分配任务.<br/>
     * @param id id
     * @return int
     */
    int updateTaskGroupFinish(@Param("id")Long id);
}
