/**
 * abssqr.com Inc.
 * Copyright (c) 2017-2019 All Rights Reserved.
 */
package com.abssqr.plat.common.facade.model.plan;

import com.abssqr.plat.common.facade.constants.AbssqrConstants;
import com.abssqr.plat.common.facade.enums.CalcTypeEnum;
import com.abssqr.plat.common.facade.enums.FeeScaleTypeEnum;
import com.abssqr.plat.common.facade.enums.FinSerFeeTypeEnum;
import com.abssqr.plat.common.facade.enums.TitleTypeEnum;
import com.general.system.common.model.BaseEntity;
import com.general.system.common.model.Money;
import com.general.system.common.util.DateTimeUtil;
import com.general.system.common.util.MoneyUtil;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 计划结算科目(收付实现）
 *
 * @author zhenxuan.luo
 * @version com.abssqr.plat.common.model.domain.plan: PlanAccountItem.java, v 0.1 2019-05-31 15:28 zhenxuan.luo Exp $
 */
public class PlanAcctTitle extends BaseEntity implements Serializable, Cloneable {

    private static final long serialVersionUID = -824828356824592734L;

    /**
     * 计划编号
     */
    private String planNo;
    /**
     * 科目编号
     */
    private String titleNo;
    /**
     * 对应金额类型编号
     */
    private String refNo;
    /**
     * 科目名称
     */
    private String titleName;
    /**
     * 科目类型
     */
    private TitleTypeEnum titleType;
    /**
     * 科目余额
     */
    private Money bal = new Money(0);
    /**
     * 总发生额-收
     */
    private Money recpAmt = new Money(0);
    /**
     * 总发生额-付
     */
    private Money payAmt = new Money(0);
    /**
     * 增值税发生额-收
     */
    private Money recpVATax = new Money(0);
    /**
     * 增值税发生额-付
     */
    private Money payVATax = new Money(0);
    /**
     * 最近结算日
     */
    private Date lastSettleDate;
    /**
     * 最近支付日
     */
    private Date lastPayDate;
    /**
     * 计费基数
     */
    private FeeScaleTypeEnum scaleType;
    /**
     * 金融服务费支付方式
     */
    private FinSerFeeTypeEnum finSerFeeType;
    /**
     * 初始额度
     */
    private Money initAmt = new Money(0);
    /**
     * 计算比例，有关联科目时用
     */
    private BigDecimal rate = BigDecimal.ZERO;
    /**
     * 计算方式
     */
    private CalcTypeEnum calcType;
    /**
     * 金额上限
     */
    private Money upperLimit = new Money(0);
    /**
     * 入账金额
     */
    private Money entryAmt = new Money(0);
    /**
     * 总金额
     */
    private BigDecimal totalAmt = BigDecimal.ZERO;
    /**
     * 起息日
     */
    private Date effectDate;

    @Override
    public PlanAcctTitle clone() {
        PlanAcctTitle newInstance = new PlanAcctTitle();
        newInstance.setPlanNo(this.getPlanNo());
        newInstance.setTitleNo(this.getTitleNo());
        newInstance.setRefNo(this.getRefNo());
        newInstance.setTitleName(this.getTitleName());
        newInstance.setTitleType(this.getTitleType());
        newInstance.setBal(this.getBal().clone());
        newInstance.setRecpAmt(this.getRecpAmt().clone());
        newInstance.setPayAmt(this.getPayAmt().clone());
        newInstance.setRecpVATax(this.getRecpVATax().clone());
        newInstance.setPayVATax(this.getPayVATax().clone());
        newInstance.setLastSettleDate(DateTimeUtil.getStandardDate(this.getLastSettleDate()));
        newInstance.setLastPayDate(DateTimeUtil.getStandardDate(this.getLastPayDate()));
        newInstance.setScaleType(this.getScaleType());
        newInstance.setInitAmt(this.getInitAmt().clone());
        newInstance.setRate(this.getRate().add(BigDecimal.ZERO));
        newInstance.setCalcType(this.getCalcType());
        newInstance.setUpperLimit(this.getUpperLimit().clone());
        newInstance.setEntryAmt(this.getEntryAmt().clone());
        newInstance.setTotalAmt(this.getTotalAmt().add(BigDecimal.ZERO));
        newInstance.setFinSerFeeType(this.getFinSerFeeType());
        newInstance.setEffectDate(this.getEffectDate());
        return newInstance;
    }

    public Money entry(BigDecimal addTotle) {
        BigDecimal newTotal = addTotle.add(this.totalAmt);
        Money newEntryAmt = new Money(newTotal, AbssqrConstants.DECIMAL_ROUNDING_MODE);
        Money thisEntryAmt = newEntryAmt.subtract(this.entryAmt);

        Money newRecpAmt = thisEntryAmt.add(this.recpAmt);
        if (this.upperLimit.isGreaterThanZero()) {
            newRecpAmt = MoneyUtil.min(newRecpAmt, this.upperLimit);
        }

        Money thisRecpAmt = newRecpAmt.subtract(this.recpAmt);
        if (thisRecpAmt.isGreaterThanZero()) {
            this.bal.addTo(thisRecpAmt);
        } else {
            thisRecpAmt = new Money(0);
        }
        this.recpAmt = newRecpAmt;
        this.entryAmt = newEntryAmt;
        this.totalAmt = newTotal;

        return thisRecpAmt;
    }

    public Money pay(Money amt) {
//        Money realAmt = MoneyUtil.min(amt, bal);
        this.bal = this.bal.subtract(amt);
        this.payAmt = this.payAmt.add(amt);
        return amt;
    }

    public Money payVTax(Money amt) {
        this.recpVATax = this.recpVATax.add(amt);
        this.payVATax = this.payVATax.add(amt);
        return amt;
    }

    public String getPlanNo() {
        return planNo;
    }

    public void setPlanNo(String planNo) {
        this.planNo = planNo;
    }

    public String getTitleNo() {
        return titleNo;
    }

    public void setTitleNo(String titleNo) {
        this.titleNo = titleNo;
    }

    public String getRefNo() {
        return refNo;
    }

    public void setRefNo(String refNo) {
        this.refNo = refNo;
    }

    public String getTitleName() {
        return titleName;
    }

    public void setTitleName(String titleName) {
        this.titleName = titleName;
    }

    public TitleTypeEnum getTitleType() {
        return titleType;
    }

    public void setTitleType(TitleTypeEnum titleType) {
        this.titleType = titleType;
    }

    public Money getBal() {
        return bal;
    }

    public void setBal(Money bal) {
        this.bal = bal;
    }

    public Money getRecpAmt() {
        return recpAmt;
    }

    public void setRecpAmt(Money recpAmt) {
        this.recpAmt = recpAmt;
    }

    public Money getPayAmt() {
        return payAmt;
    }

    public void setPayAmt(Money payAmt) {
        this.payAmt = payAmt;
    }

    public Money getRecpVATax() {
        return recpVATax;
    }

    public void setRecpVATax(Money recpVATax) {
        this.recpVATax = recpVATax;
    }

    public Money getPayVATax() {
        return payVATax;
    }

    public void setPayVATax(Money payVATax) {
        this.payVATax = payVATax;
    }

    public Date getLastSettleDate() {
        return lastSettleDate;
    }

    public void setLastSettleDate(Date lastSettleDate) {
        this.lastSettleDate = lastSettleDate;
    }

    public Date getLastPayDate() {
        return lastPayDate;
    }

    public void setLastPayDate(Date lastPayDate) {
        this.lastPayDate = lastPayDate;
    }

    public FeeScaleTypeEnum getScaleType() {
        return scaleType;
    }

    public void setScaleType(FeeScaleTypeEnum scaleType) {
        this.scaleType = scaleType;
    }

    public Money getInitAmt() {
        return initAmt;
    }

    public void setInitAmt(Money initAmt) {
        this.initAmt = initAmt;
    }

    public BigDecimal getRate() {
        return rate;
    }

    public void setRate(BigDecimal rate) {
        this.rate = rate;
    }

    public CalcTypeEnum getCalcType() {
        return calcType;
    }

    public void setCalcType(CalcTypeEnum calcType) {
        this.calcType = calcType;
    }

    public Money getUpperLimit() {
        return upperLimit;
    }

    public void setUpperLimit(Money upperLimit) {
        this.upperLimit = upperLimit;
    }

    public Money getEntryAmt() {
        return entryAmt;
    }

    public void setEntryAmt(Money entryAmt) {
        this.entryAmt = entryAmt;
    }

    public BigDecimal getTotalAmt() {
        return totalAmt;
    }

    public void setTotalAmt(BigDecimal totalAmt) {
        this.totalAmt = totalAmt;
    }

    public FinSerFeeTypeEnum getFinSerFeeType() {
        return finSerFeeType;
    }

    public void setFinSerFeeType(FinSerFeeTypeEnum finSerFeeType) {
        this.finSerFeeType = finSerFeeType;
    }

    public Date getEffectDate() {
        return effectDate;
    }

    public void setEffectDate(Date effectDate) {
        this.effectDate = effectDate;
    }
}