/**
 * abssqr.com Inc. 
 * Copyright (c) 2017-2020 All Rights Reserved. 
 */
package com.abssqr.plat.common.facade.model.trans;

import cn.hutool.core.util.StrUtil;
import com.abssqr.plat.common.facade.enums.AccountAttributeEnum;
import com.abssqr.plat.common.facade.enums.PlanCapitalTransTypeEnum;
import com.abssqr.plat.common.facade.enums.PlanTypeEnum;
import com.abssqr.plat.common.facade.enums.TransCodeEnum;
import com.general.system.common.model.BaseEntity;

/**
 * 交易及交易双方
 * @author hanfei
 * @version $Id: CapitalTrader.java, v 0.1 2020-02-13 8:22 PM hanfei Exp $ 
 */
public class CapitalTrader extends BaseEntity{
    
    /**
     * 发起方机构编码
     */
    private String              intPtyCode;
    /**
     * 发起方机构类型
     */
    private PlanTypeEnum        intPtyType;
    
    /**
     * 发起方机构编码
     */
    private String              cntPtyCode;
    /**
     * 发起方机构类型
     */
    private PlanTypeEnum        cntPtyType;
    /**
     * 交易编码
     */
    private TransCodeEnum       transCode;
    /**
     * 交易类型
     */
    private PlanCapitalTransTypeEnum capitalTransType;
    
    
    private CapitalTrader(){}
    
    public CapitalTrader(String intPtyCode, PlanTypeEnum intPtyType, String cntPtyCode,
                         PlanTypeEnum cntPtyType, TransCodeEnum transCode) {
        this.intPtyCode = intPtyCode;
        this.intPtyType = intPtyType;
        this.cntPtyCode = cntPtyCode;
        this.cntPtyType = cntPtyType;
        this.transCode = transCode;
    }
    
    public CapitalTrader(String intPtyCode, PlanTypeEnum intPtyType, String cntPtyCode,
                         PlanTypeEnum cntPtyType, PlanCapitalTransTypeEnum capitalTransType) {
        this.intPtyCode = intPtyCode;
        this.intPtyType = intPtyType;
        this.cntPtyCode = cntPtyCode;
        this.cntPtyType = cntPtyType;
        this.transCode = capitalTransType.getTransCode();
        this.capitalTransType = capitalTransType;
    }
    /**
     * 判断是否操作对手方水位金额
     * 1、发起方与对手方一致
     *   不操作对手方水位，对应场景：
     *      1、"PCT04", "承接池分配"
     *      2、"PCT11", "未转资产回收划账"
     *      3、"PCT12", "资产交易兑付划账"
     *      4、"PCT14", "应付利息兑付回收划账"
     *      5、"PCT16", "放款池分配"
     *      6、"PCT20", "向回款户资金划账"
     * 2、对手方账户为放款户
     *   不操作对手方水位，对应场景：
     *      1、"PCT05", "放款冲正"
     *      2、"PCT22", "回购卖出资产-目标放款池"
     * @return
     */
    public boolean isChangeCntPty(){
        if (! this.isTransfer() ||
            // 对手机构账户属性 为 放款户
            capitalTransType.getDesAcct().getAttribute() == AccountAttributeEnum.PAY) {
            return false;
        }
        return true;
    }
    
    /**
     * 是否转让交易
     * @return
     */
    public boolean isTransfer(){
        return ! StrUtil.equals(this.getIntPtyCode(), this.getCntPtyCode());
    }
    
    /**
     * 交易单类型
     */
    public PlanCapitalTransTypeEnum getCapitalTransType() {
        if (capitalTransType == null){
            capitalTransType = PlanCapitalTransTypeEnum.getCapitalTransType(this);
        }
        return capitalTransType;
    }
    
    public void setCapitalTransType(PlanCapitalTransTypeEnum capitalTransType) {
        this.capitalTransType = capitalTransType;
    }
    
    public String getIntPtyCode() {
        return intPtyCode;
    }
    
    public void setIntPtyCode(String intPtyCode) {
        this.intPtyCode = intPtyCode;
    }
    
    public PlanTypeEnum getIntPtyType() {
        return intPtyType;
    }
    
    public void setIntPtyType(PlanTypeEnum intPtyType) {
        this.intPtyType = intPtyType;
    }
    
    public String getCntPtyCode() {
        return cntPtyCode;
    }
    
    public void setCntPtyCode(String cntPtyCode) {
        this.cntPtyCode = cntPtyCode;
    }
    
    public PlanTypeEnum getCntPtyType() {
        return cntPtyType;
    }
    
    public void setCntPtyType(PlanTypeEnum cntPtyType) {
        this.cntPtyType = cntPtyType;
    }
    
    public TransCodeEnum getTransCode() {
        return transCode;
    }
    
    public void setTransCode(TransCodeEnum transCode) {
        this.transCode = transCode;
    }
    
}
