/**
 * abssqr.com Inc. 
 * Copyright (c) 2017-2019 All Rights Reserved. 
 */
package com.abssqr.plat.common.facade.model.trans;

import cn.hutool.json.JSONUtil;
import com.abssqr.plat.common.facade.enums.StageChangeTypeEnum;
import com.abssqr.plat.common.facade.model.plan.PlanCapitalOrder;
import com.general.system.common.model.Money;

import java.util.Date;

/**
 * 水位变化参数
 * @author hanfei
 * @version $Id: ChangeStageParam.java, v 0.1 2019-10-13 3:27 PM hanfei Exp $ 
 */
public class ChangeStageParam {
    
    /**
     * 交易双方
     */
    private CapitalTrader       capitalTrader;
    /**
     * 会计日
     */
    private Date                accountDate;
    /**
     * 变化水位阶段
     */
    private StageChangeTypeEnum changeType;
    /**
     * 交易金额
     */
    private Money               transAmt = new Money();
    /**
     * 清算金额
     */
    private Money               clearToWayAmt;
    /**
     * 交易编码
     */
    private String              transBizNo;
    /**
     * 扩展信息
     */
    private String              extInf;
    
    private ChangeStageParam(){}
    
    public static ChangeStageParam createParamByCapital(CapitalTrader capitalTrader, StageChangeTypeEnum changeType,
                                                        PlanCapitalOrder capitalOrder) {
        ChangeStageParam param = new ChangeStageParam();
        param.setCapitalTrader(capitalTrader);
        param.setAccountDate(capitalOrder.getAccountDate());
        param.setChangeType(changeType);
        param.setTransAmt(capitalOrder.getTransAmt());
        param.setClearToWayAmt(capitalOrder.getPayableAmt());
        param.setTransBizNo(capitalOrder.getSeqNo());
        param.setExtInf(JSONUtil.toJsonStr(capitalOrder));
        return param;
    }
    
    public static ChangeStageParam createParamByClearing(CapitalTrader capitalTrader, StageChangeTypeEnum changeType,
                                                         PlanClearingOrder clearingOrder) {
        ChangeStageParam param = new ChangeStageParam();
        param.setCapitalTrader(capitalTrader);
        param.setAccountDate(clearingOrder.getAccountDate());
        param.setChangeType(changeType);
        param.setTransAmt(clearingOrder.getTransAmt());
        param.setTransBizNo(clearingOrder.getSeqNo());
        param.setExtInf(JSONUtil.toJsonStr(clearingOrder));
        return param;
    }
    
    
    public StageChangeTypeEnum getChangeType() {
        return changeType;
    }
    
    public void setChangeType(StageChangeTypeEnum changeType) {
        this.changeType = changeType;
    }
    
    public Money getTransAmt() {
        return transAmt;
    }
    
    public void setTransAmt(Money transAmt) {
        this.transAmt = transAmt;
    }
    
    public String getTransBizNo() {
        return transBizNo;
    }
    
    public void setTransBizNo(String transBizNo) {
        this.transBizNo = transBizNo;
    }
    
    public String getExtInf() {
        return extInf;
    }
    
    public void setExtInf(String extInf) {
        this.extInf = extInf;
    }
    
    public Date getAccountDate() {
        return accountDate;
    }
    
    public void setAccountDate(Date accountDate) {
        this.accountDate = accountDate;
    }
    
    public Money getClearToWayAmt() {
        return clearToWayAmt;
    }
    
    public void setClearToWayAmt(Money clearToWayAmt) {
        this.clearToWayAmt = clearToWayAmt;
    }
    
    public CapitalTrader getCapitalTrader() {
        return capitalTrader;
    }
    
    public void setCapitalTrader(CapitalTrader capitalTrader) {
        this.capitalTrader = capitalTrader;
    }
}
