/**
 * abssqr.com Inc. 
 * Copyright (c) 2017-2019 All Rights Reserved. 
 */
package com.abssqr.plat.common.facade.result.ast;

import com.abssqr.plat.common.facade.enums.AstContractTypeEnum;
import com.abssqr.plat.common.facade.enums.CertTypeEnum;
import com.abssqr.plat.common.facade.enums.LoanStatusEnum;
import com.abssqr.plat.common.facade.enums.LoanTypeEnum;
import com.abssqr.plat.common.facade.enums.OwnStatusEnum;
import com.abssqr.plat.common.facade.enums.PeriodTypeEnum;
import com.abssqr.plat.common.facade.enums.RateTypeEnum;
import com.abssqr.plat.common.facade.enums.RepayMethodEnum;
import com.abssqr.plat.common.facade.result.PlanConst;
import com.alibaba.fastjson.annotation.JSONField;
import com.general.system.common.model.Money;

import java.math.BigDecimal;
import java.util.Date;

/**
 *
 * @author hanfei
 * @version $Id: LoanContractDetail.java, v 0.1 2019-12-12 6:32 PM hanfei Exp $ 
 */
public class LoanContractDetail {
    /**
     * 合同ID
     */
    private String contNo;
    
    /**
     * 内部合同id
     */
    private String outContNo;
    
    /**
     * 内部产品码
     */
    private String prodNo;
    
    /**
     * 合同类型
     */
    private AstContractTypeEnum contractType;
    /**
     * 开始日期
     */
    @JSONField(format="yyyy-MM-dd")
    private Date startDate;
    
    /**
     * 结束日期
     */
    @JSONField(format="yyyy-MM-dd")
    private Date endDate;
    
    /**
     * 签署生效时间
     */
    @JSONField(format="yyyy-MM-dd")
    private Date effectDate;
    /**
     * 权益归属机构
     */
    private String lenderOrgCode;
    /**
     * 资产编号
     */
    private String astNo;
    
    /**
     * 用户ID
     */
    private String userId;
    
    /**
     * 外部资产编号
     */
    private String outAstNo;
    /**
     * 发放金额
     */
    private Money disbAmount = new Money(0);
    /**
     * 支用日期（放款日期）
     */
    @JSONField(format="yyyy-MM-dd")
    private Date disbDate;
    /**
     * 客户号
     */
    private String name;
    
    /**
     * 证件类型
     */
    private CertTypeEnum certType;
    
    /**
     * 证件号
     */
    private String certNo;
    
    /**
     * 手机号
     */
    private String mobileNo;
    
    /**
     * 省份
     */
    private String province;
    
    /**
     * 城市
     */
    private String city;
    
    /**
     * 还款方式
     */
    private RepayMethodEnum repayMethod;
    
//    /**
//     * 还款周期
//     */
//    private int repayPeriod;
    
    /**
     * 还款周期类型
     */
    private PeriodTypeEnum repayPeriodType;
    
//    /**
//     * 年化天数
//     */
//    private Integer rateDays;
    
    /**
     * 初始利率
     */
    private BigDecimal rate = BigDecimal.ZERO;
    /**
     * 利率（描述）
     */
    private String          rateDesc;
    
//    /**
//     * 初始年化利率
//     */
//    private BigDecimal pnyRate = BigDecimal.ZERO;
    
    /**
     * 利率类型
     */
    private RateTypeEnum rateType;
    
    /**
     * 分期数
     */
    private int termCnt;
    
    /**
     * 贷款类型
     */
    private LoanTypeEnum   loanType;
//    /**
//     * 贷款用途
//     */
//    private String purpose;
    /**
     * 资产归属状态
     */
    private OwnStatusEnum  ownStatus;
    /**
     * 资产状态
     */
    private LoanStatusEnum status;
    
    public String getContNo() {
        return contNo;
    }
    
    public void setContNo(String contNo) {
        this.contNo = contNo;
    }
    
    public String getOutContNo() {
        return outContNo;
    }
    
    public void setOutContNo(String outContNo) {
        this.outContNo = outContNo;
    }
    
    public String getProdNo() {
        return prodNo;
    }
    
    public void setProdNo(String prodNo) {
        this.prodNo = prodNo;
    }
    
    public AstContractTypeEnum getContractType() {
        return contractType;
    }
    
    public void setContractType(AstContractTypeEnum contractType) {
        this.contractType = contractType;
    }
    
    public Date getStartDate() {
        return startDate;
    }
    
    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }
    
    public Date getEndDate() {
        return endDate;
    }
    
    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }
    
    public Date getEffectDate() {
        return effectDate;
    }
    
    public void setEffectDate(Date effectDate) {
        this.effectDate = effectDate;
    }
    
    public String getLenderOrgCode() {
        return lenderOrgCode;
    }
    
    public String getLenderOrgName() {
        return PlanConst.getPlanName(lenderOrgCode);
    }
    
    public void setLenderOrgCode(String lenderOrgCode) {
        this.lenderOrgCode = lenderOrgCode;
    }
    
    public String getAstNo() {
        return astNo;
    }
    
    public void setAstNo(String astNo) {
        this.astNo = astNo;
    }
    
    public String getUserId() {
        return userId;
    }
    
    public void setUserId(String userId) {
        this.userId = userId;
    }
    
    public String getOutAstNo() {
        return outAstNo;
    }
    
    public void setOutAstNo(String outAstNo) {
        this.outAstNo = outAstNo;
    }
    
    public Money getDisbAmount() {
        return disbAmount;
    }
    
    public void setDisbAmount(Money disbAmount) {
        this.disbAmount = disbAmount;
    }
    
    public Date getDisbDate() {
        return disbDate;
    }
    
    public void setDisbDate(Date disbDate) {
        this.disbDate = disbDate;
    }
    
    public String getName() {
        return name;
    }
    
    public void setName(String name) {
        this.name = name;
    }
    
    public CertTypeEnum getCertType() {
        return certType;
    }
    
    public void setCertType(CertTypeEnum certType) {
        this.certType = certType;
    }
    
    public String getCertNo() {
        return certNo;
    }
    
    public void setCertNo(String certNo) {
        this.certNo = certNo;
    }
    
    public String getMobileNo() {
        return mobileNo;
    }
    
    public void setMobileNo(String mobileNo) {
        this.mobileNo = mobileNo;
    }
    
    public String getProvince() {
        return province;
    }
    
    public void setProvince(String province) {
        this.province = province;
    }
    
    public String getCity() {
        return city;
    }
    
    public void setCity(String city) {
        this.city = city;
    }
    
    public RepayMethodEnum getRepayMethod() {
        return repayMethod;
    }
    
    public void setRepayMethod(RepayMethodEnum repayMethod) {
        this.repayMethod = repayMethod;
    }
    
    public PeriodTypeEnum getRepayPeriodType() {
        return repayPeriodType;
    }
    
    public void setRepayPeriodType(PeriodTypeEnum repayPeriodType) {
        this.repayPeriodType = repayPeriodType;
    }
    
    public BigDecimal getRate() {
        return rate;
    }
    
    public void setRate(BigDecimal rate) {
        this.rate = rate;
    }
    
    public RateTypeEnum getRateType() {
        return rateType;
    }
    
    public void setRateType(RateTypeEnum rateType) {
        this.rateType = rateType;
    }
    
    public int getTermCnt() {
        return termCnt;
    }
    
    public void setTermCnt(int termCnt) {
        this.termCnt = termCnt;
    }
    
    public LoanTypeEnum getLoanType() {
        return loanType;
    }
    
    public void setLoanType(LoanTypeEnum loanType) {
        this.loanType = loanType;
    }
    
    public String getRateDesc() {
        return rateDesc;
    }
    
    public void setRateDesc(String rateDesc) {
        this.rateDesc = rateDesc;
    }
    
    public OwnStatusEnum getOwnStatus() {
        return ownStatus;
    }
    
    public void setOwnStatus(OwnStatusEnum ownStatus) {
        this.ownStatus = ownStatus;
    }
    
    public LoanStatusEnum getStatus() {
        return status;
    }
    
    public void setStatus(LoanStatusEnum status) {
        this.status = status;
    }
}
