/**
 * abssqr.comInc.
 * Copyright(c)2019-2019AllRightsReserved.
 */
package com.abssqr.plat.common.model.convertor;

import com.abssqr.plat.common.facade.enums.IntrTypeEnum;
import com.abssqr.plat.common.facade.enums.LayerTypeEnu;
import com.abssqr.plat.common.facade.model.plan.InvestStructure;
import com.abssqr.plat.common.facade.param.plan.sub.InvestStructureParam;
import com.abssqr.plat.common.facade.utils.CalcUtil;
import com.abssqr.plat.common.model.enums.IdTypeEnum;
import com.abssqr.plat.common.model.seq.SequenceUtil;
import com.general.system.common.model.Money;
import com.general.system.tool.util.ToolUtil;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

/**
 *投资结构转换器
 *
 * @author yangcheng
 * @version InvestStructureConvert.java, v0.12019-08-2716:50 yangchengExp$
 */
public class InvestStructureConvert {
    
    /**
     * 投资结构模型转换
     * @param param
     * @return
     */
    public static List<InvestStructure> convert2InvestStructureList(List<InvestStructureParam> param) {
        List<InvestStructure> investStructureList = new ArrayList();
        if (CollectionUtils.isEmpty(param)) {
            return investStructureList;
        }
        for (InvestStructureParam nvestStructureParam : param) {
            InvestStructure result = new InvestStructure();
            //layerAmt 层级规模
            result.setLayerAmt(new Money(nvestStructureParam.getLayerAmt()).multiply(10000));
            //layerNo 编号
            result.setLayerNo(nvestStructureParam.getLayerNo());
            if (StringUtils.isBlank(result.getLayerNo())) {
                result.setLayerNo(SequenceUtil.genId(IdTypeEnum.INVESTSTRUCTURE));
            }
            //intrType 利率类型
            if (ToolUtil.isEmpty(nvestStructureParam.getLayerIntr()) ||
                BigDecimal.ZERO.compareTo(nvestStructureParam.getLayerIntr()) == 0) {
                nvestStructureParam.setIntrType(IntrTypeEnum.NOTICKET.getCode());
            }
            result.setIntrType(IntrTypeEnum.getByCode(nvestStructureParam.getIntrType()));
            //layerName 层次名称
            result.setLayerName(nvestStructureParam.getLayerName());
            //layerType 层级类型
            result.setLayerType(LayerTypeEnu.getByCode(nvestStructureParam.getLayerType()));
            //layerEndDate 到期日
            result.setLayerEndDate(nvestStructureParam.getLayerEndDate());
            //layerIntr 层级利率
            result.setLayerIntr(CalcUtil.calcRealRate(nvestStructureParam.getLayerIntr()));
            // 起息日
            result.setEffectDate(nvestStructureParam.getEffectDate());
            result.setAppend(nvestStructureParam.getAppend());
            investStructureList.add(result);
        }
        return investStructureList;
    }
}
