/**
 * abssqr.com Inc.
 * Copyright (c) 2017-2018 All Rights Reserved.
 */

package com.abssqr.plat.common.model.convertor;

import com.abssqr.plat.common.dal.mysql.auto.dataobject.LoanBakDO;
import com.abssqr.plat.common.dal.mysql.auto.dataobject.LoanDO;
import com.abssqr.plat.common.dal.mysql.auto.resultmap.AstPoolLoan;
import com.abssqr.plat.common.facade.enums.*;
import com.abssqr.plat.common.facade.result.ast.AstPoolLoanListVO;
import com.abssqr.plat.common.model.domain.ast.Loan;
import com.abssqr.plat.common.model.domain.ast.LoanBak;
import com.abssqr.plat.common.model.domain.ast.LoanRisk;
import com.abssqr.plat.common.model.utils.TextUtil;
import com.general.system.tool.util.ToolUtil;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Optional;

/**
 * @author guozhenhua
 * @version com.abssqr.plat.common.model.convertor: LoanConvert.java, v 0.1 2018-03-07 下午4:14 guozhenhua Exp $
 */
public class LoanConvert {

    public static Loan convert2Domain(LoanDO var) {
        if (var == null) {
            return null;
        }

        Loan instance = new Loan(false);
        instance.setAstNo(var.getAstNo());
        instance.setUserId(var.getUserId());
        instance.setOutAstNo(var.getOutAstNo());
        instance.setContNo(var.getContractNo());
        instance.setProdNo(var.getProdNo());
        //添加相应数据
        instance.getAstOrg().setSponsorOrgCode(var.getSponserOrgCode());
        instance.getAstOrg().setManagerOrgCode(var.getManagerOrgCode());
        instance.getAstOrg().getAstOwnership().setLastOwnOrg(var.getLastOwnOrg());
        instance.getAstOrg().getAstOwnership().setLenderOrgCode(var.getLenderOrgCode());
        instance.getAstOrg().getAstOwnership().setOwnOrg(var.getOwnOrg());
        instance.getAstOrg().getAstOwnership().setOwnStatus(OwnStatusEnum.getByCode(var.getOwnStatus()));
        instance.getAstPeriod().setEndDate(var.getEndDate());
        instance.getAstPeriod().setStartDate(var.getStartDate());
        instance.getAstPeriod().setInDate(var.getInDate());
        instance.getAstPeriod().setDisbDate(var.getDisbDate());
        instance.getAstPeriod().setClearDate(var.getClearDate());
        instance.setOwnPack(var.getOwnPack());
        instance.setCurTerm(var.getCurTerm());
        instance.setTermCnt(var.getTermCnt());
        instance.getBal().setByFieldType(DebtMoneyFieldEnum.PRIN, var.getPrinBal());
        instance.getBal().setByFieldType(DebtMoneyFieldEnum.OVD_PRIN, var.getOvdPrinBal());
        instance.getBal().setByFieldType(DebtMoneyFieldEnum.OVD_INTR, var.getOvdIntrBal());
        instance.getBal().setByFieldType(DebtMoneyFieldEnum.OVD_FEE, var.getOvdFeeBal());
        instance.getBal().setByFieldType(DebtMoneyFieldEnum.PRIN_ODUE_PNY, var.getPrinPenalBal());
        instance.getBal().setByFieldType(DebtMoneyFieldEnum.INTR, var.getIntrBal());
        instance.getBal().setByFieldType(DebtMoneyFieldEnum.INTR_ODUE_PNY, var.getIntrPenalBal());
        instance.getBal().setByFieldType(DebtMoneyFieldEnum.FEE, var.getFeeBal());
        instance.getBal().setByFieldType(DebtMoneyFieldEnum.FEE_PNY, var.getFeePenalBal());
        instance.getBal().setByFieldType(DebtMoneyFieldEnum.OTHER_FEE, var.getOtherFeeBal());
        instance.getBal().setByFieldType(DebtMoneyFieldEnum.OTHER_FEE_PNY, var.getOtherFeePenalBal());
        instance.getPaid().setByFieldType(DebtMoneyFieldEnum.PRIN, var.getPaidPrinAmt());
        instance.getPaid().setByFieldType(DebtMoneyFieldEnum.PRIN_ODUE_PNY, var.getPaidPrinPenalAmt());
        instance.getPaid().setByFieldType(DebtMoneyFieldEnum.INTR, var.getPaidIntrAmt());
        instance.getPaid().setByFieldType(DebtMoneyFieldEnum.INTR_ODUE_PNY, var.getPaidIntrPenalAmt());
        instance.getPaid().setByFieldType(DebtMoneyFieldEnum.FEE, var.getPaidFeeAmt());
        instance.getPaid().setByFieldType(DebtMoneyFieldEnum.FEE_PNY, var.getPaidFeePenalAmt());
        instance.getPaid().setByFieldType(DebtMoneyFieldEnum.OTHER_FEE, var.getPaidOtherFeeAmt());
        instance.getPaid().setByFieldType(DebtMoneyFieldEnum.OTHER_FEE_PNY, var.getPaidOtherFeePenalAmt());
        instance.setStatus(LoanStatusEnum.getByCode(var.getStatus()));
        instance.setLoanRisk(new LoanRisk(var.getOvdDays(), AstRiskClassEnum.getByCode(var.getRiskCl())));
        instance.getLoanRisk().setWtfStatus(ToolUtil.isEmpty(var.getWtfStatus()) ? YNEnum.N : YNEnum.getByCode(var.getWtfStatus()));
        instance.setLastUpdateDate(var.getLastUpdateDate());
        instance.setOutProdNo(var.getOutProdNo());
        instance.setCertNo(var.getCertNo());
        instance.setTransCnt((var.getTransCnt() == null) ? 0 : var.getTransCnt());
        instance.setCapitalNo(var.getCapitalNo() == null ? CapitalAstMatchEnum.DEFAULT.getCode() : var.getCapitalNo());
        instance.setLayerName(var.getLayerName());
        instance.setExtInf(TextUtil.convertTxt2Map(var.getExtInf()));
        return instance;
    }

    public static LoanDO convert2DO(Loan var) {
        if (var == null) {
            return null;
        }

        LoanDO instance = new LoanDO();

        instance.setAstNo(var.getAstNo());
        instance.setUserId(var.getUserId());
        instance.setOutAstNo(var.getOutAstNo());
        instance.setContractNo(var.getContNo());
        instance.setProdNo(var.getProdNo());

        instance.setOwnOrg(var.getAstOrg().getAstOwnership().getOwnOrg());
        instance.setLastOwnOrg(var.getAstOrg().getAstOwnership().getLastOwnOrg());
        instance.setLenderOrgCode(var.getAstOrg().getAstOwnership().getLenderOrgCode());
        instance.setManagerOrgCode(var.getAstOrg().getManagerOrgCode());
        instance.setSponserOrgCode(var.getAstOrg().getSponsorOrgCode());
        instance.setOwnStatus(var.getAstOrg().getAstOwnership().getOwnStatus().getCode());
        instance.setOwnPack(var.getOwnPack());

        instance.setPrinBal(var.getBal().getByFieldType(DebtMoneyFieldEnum.PRIN));
        instance.setOvdPrinBal(var.getBal().getByFieldType(DebtMoneyFieldEnum.OVD_PRIN));
        instance.setOvdIntrBal(var.getBal().getByFieldType(DebtMoneyFieldEnum.OVD_INTR));
        instance.setOvdFeeBal(var.getBal().getByFieldType(DebtMoneyFieldEnum.OVD_FEE));

        instance.setPrinPenalBal(var.getBal().getByFieldType(DebtMoneyFieldEnum.PRIN_ODUE_PNY));
        instance.setIntrBal(var.getBal().getByFieldType(DebtMoneyFieldEnum.INTR));
        instance.setIntrPenalBal(var.getBal().getByFieldType(DebtMoneyFieldEnum.INTR_ODUE_PNY));
        instance.setFeeBal(var.getBal().getByFieldType(DebtMoneyFieldEnum.FEE));
        instance.setFeePenalBal(var.getBal().getByFieldType(DebtMoneyFieldEnum.FEE_PNY));
        instance.setOtherFeeBal(var.getBal().getByFieldType(DebtMoneyFieldEnum.OTHER_FEE));
        instance.setOtherFeePenalBal(var.getBal().getByFieldType(DebtMoneyFieldEnum.OTHER_FEE_PNY));

        instance.setPaidPrinAmt(var.getPaid().getByFieldType(DebtMoneyFieldEnum.PRIN));
        instance.setPaidPrinPenalAmt(var.getPaid().getByFieldType(DebtMoneyFieldEnum.PRIN_ODUE_PNY));
        instance.setPaidIntrAmt(var.getPaid().getByFieldType(DebtMoneyFieldEnum.INTR));
        instance.setPaidIntrPenalAmt(var.getPaid().getByFieldType(DebtMoneyFieldEnum.INTR_ODUE_PNY));
        instance.setPaidFeeAmt(var.getPaid().getByFieldType(DebtMoneyFieldEnum.FEE));
        instance.setPaidFeePenalAmt(var.getPaid().getByFieldType(DebtMoneyFieldEnum.FEE_PNY));
        instance.setPaidOtherFeeAmt(var.getPaid().getByFieldType(DebtMoneyFieldEnum.OTHER_FEE));
        instance.setPaidOtherFeePenalAmt(var.getPaid().getByFieldType(DebtMoneyFieldEnum.OTHER_FEE_PNY));

        instance.setRiskCl(var.getLoanRisk().getRiskClass().getCode());
        instance.setStatus(var.getStatus().getCode());
        instance.setWtfStatus(var.getLoanRisk().getWtfStatus().getCode());
        instance.setCurTerm(var.getCurTerm());
        instance.setOvdDays(var.getLoanRisk().getOvdDays());
        instance.setTermCnt(var.getTermCnt());
        instance.setInDate(var.getAstPeriod().getInDate());
        instance.setEndDate(var.getAstPeriod().getEndDate());
        instance.setClearDate(var.getAstPeriod().getClearDate());
        instance.setStartDate(var.getAstPeriod().getStartDate());
        instance.setDisbDate(var.getAstPeriod().getDisbDate());
        instance.setLastUpdateDate(var.getLastUpdateDate());
        instance.setOutProdNo(var.getOutProdNo());
        instance.setCertNo(var.getCertNo());
        instance.setTransCnt(var.getTransCnt());
        instance.setCapitalNo(var.getCapitalNo() == null ? CapitalAstMatchEnum.DEFAULT.getCode() : var.getCapitalNo());
        instance.setLayerName(var.getLayerName());
        instance.setExtInf(TextUtil.convertMap2Txt(var.getExtInf()));
        return instance;
    }

    public static LoanBakDO convert2BakDO(LoanBak loanBak) {
        if (loanBak == null || loanBak.getLoan() == null) {
            return null;
        }

        Loan var = loanBak.getLoan();
        Date bakDate = loanBak.getBakDate();
        LoanBakDO instance = new LoanBakDO();
        instance.setBakDate(bakDate);

        instance.setAstNo(var.getAstNo());
        instance.setUserId(var.getUserId());
        instance.setOutAstNo(var.getOutAstNo());
        instance.setContractNo(var.getContNo());
        instance.setProdNo(var.getProdNo());

        instance.setOwnOrg(var.getAstOrg().getAstOwnership().getOwnOrg());
        instance.setLastOwnOrg(var.getAstOrg().getAstOwnership().getLastOwnOrg());
        instance.setLenderOrgCode(var.getAstOrg().getAstOwnership().getLenderOrgCode());
        instance.setManagerOrgCode(var.getAstOrg().getManagerOrgCode());
        instance.setSponserOrgCode(var.getAstOrg().getSponsorOrgCode());
        instance.setOwnStatus(var.getAstOrg().getAstOwnership().getOwnStatus().getCode());
        instance.setOwnPack(var.getOwnPack());

        instance.setPrinBal(var.getBal().getByFieldType(DebtMoneyFieldEnum.PRIN));
        instance.setOvdPrinBal(var.getBal().getByFieldType(DebtMoneyFieldEnum.OVD_PRIN));
        instance.setOvdIntrBal(var.getBal().getByFieldType(DebtMoneyFieldEnum.OVD_INTR));
        instance.setOvdFeeBal(var.getBal().getByFieldType(DebtMoneyFieldEnum.OVD_FEE));

        instance.setPrinPenalBal(var.getBal().getByFieldType(DebtMoneyFieldEnum.PRIN_ODUE_PNY));
        instance.setIntrBal(var.getBal().getByFieldType(DebtMoneyFieldEnum.INTR));
        instance.setIntrPenalBal(var.getBal().getByFieldType(DebtMoneyFieldEnum.INTR_ODUE_PNY));
        instance.setFeeBal(var.getBal().getByFieldType(DebtMoneyFieldEnum.FEE));
        instance.setFeePenalBal(var.getBal().getByFieldType(DebtMoneyFieldEnum.FEE_PNY));
        instance.setOtherFeeBal(var.getBal().getByFieldType(DebtMoneyFieldEnum.OTHER_FEE));
        instance.setOtherFeePenalBal(var.getBal().getByFieldType(DebtMoneyFieldEnum.OTHER_FEE_PNY));

        instance.setPaidPrinAmt(var.getPaid().getByFieldType(DebtMoneyFieldEnum.PRIN));
        instance.setPaidPrinPenalAmt(var.getPaid().getByFieldType(DebtMoneyFieldEnum.PRIN_ODUE_PNY));
        instance.setPaidIntrAmt(var.getPaid().getByFieldType(DebtMoneyFieldEnum.INTR));
        instance.setPaidIntrPenalAmt(var.getPaid().getByFieldType(DebtMoneyFieldEnum.INTR_ODUE_PNY));
        instance.setPaidFeeAmt(var.getPaid().getByFieldType(DebtMoneyFieldEnum.FEE));
        instance.setPaidFeePenalAmt(var.getPaid().getByFieldType(DebtMoneyFieldEnum.FEE_PNY));
        instance.setPaidOtherFeeAmt(var.getPaid().getByFieldType(DebtMoneyFieldEnum.OTHER_FEE));
        instance.setPaidOtherFeePenalAmt(var.getPaid().getByFieldType(DebtMoneyFieldEnum.OTHER_FEE_PNY));

        instance.setRiskCl(var.getLoanRisk().getRiskClass().getCode());
        instance.setStatus(var.getStatus().getCode());
        instance.setAstStatus(loanBak.getAstStatus() != null ? loanBak.getAstStatus().getCode() : "");
        instance.setWtfStatus(var.getLoanRisk().getWtfStatus().getCode());
        instance.setCurTerm(var.getCurTerm());
        instance.setOvdDays(var.getLoanRisk().getOvdDays());
        instance.setTermCnt(var.getTermCnt());
        instance.setInDate(var.getAstPeriod().getInDate());
        instance.setEndDate(var.getAstPeriod().getEndDate());
        instance.setClearDate(var.getAstPeriod().getClearDate());
        instance.setStartDate(var.getAstPeriod().getStartDate());
        instance.setDisbDate(var.getAstPeriod().getDisbDate());
        instance.setLastUpdateDate(var.getLastUpdateDate());
        instance.setOutProdNo(var.getOutProdNo());
        instance.setCertNo(var.getCertNo());
        instance.setCost(loanBak.getCost());
        instance.setAstOvdDays(loanBak.getAstOvdDays());
        instance.setRate(loanBak.getRate());
        instance.setRateType(loanBak.getRateType().getCode());
        instance.setRateDays(loanBak.getRateDays());
        instance.setCapitalNo(var.getCapitalNo() == null ? CapitalAstMatchEnum.DEFAULT.getCode() : var.getCapitalNo());
        instance.setLayerName(var.getLayerName());
        instance.setExtInf(TextUtil.convertMap2Txt(var.getExtInf()));
        return instance;
    }


    public static List<AstPoolLoanListVO> convert2AstPoolLoanListVOs(List<AstPoolLoan> astPoolLoanList){
        List<AstPoolLoanListVO> loanListVOS=new ArrayList<>();
        astPoolLoanList.forEach(v->{
            loanListVOS.add(convert2AstPoolLoanListVO(v));
        });
        return loanListVOS;
    }

    public static AstPoolLoanListVO convert2AstPoolLoanListVO(AstPoolLoan astPoolLoan){
        AstPoolLoanListVO astPoolLoanListVO=new AstPoolLoanListVO();
        astPoolLoanListVO.setAstNo(astPoolLoan.getAstNo());
        astPoolLoanListVO.setFreeTerm(astPoolLoan.getFreeTerm());
        astPoolLoanListVO.setPlanName(astPoolLoan.getPlanName());
        astPoolLoanListVO.setPrinBal(astPoolLoan.getPrinBal());
        astPoolLoanListVO.setRate(astPoolLoan.getRate());
        astPoolLoanListVO.setRepayMethod(astPoolLoan.getRepayMethod());
        astPoolLoanListVO.setRepayPeriod(astPoolLoan.getRepayPeriod());
        astPoolLoanListVO.setRepoayPeriodType(astPoolLoan.getRepayPeriodType());
        astPoolLoanListVO.setRiskCl(astPoolLoan.getRiskCl());
        astPoolLoanListVO.setStartDate(astPoolLoan.getStartDate());
        return astPoolLoanListVO;
    }
}
