/**
 * abssqr.com Inc. 
 * Copyright (c) 2017-2019 All Rights Reserved. 
 */
package com.abssqr.plat.common.model.convertor;

import com.abssqr.plat.common.dal.mysql.auto.dataobject.PlanClearingOrderDO;
import com.abssqr.plat.common.dal.mysql.auto.resultmap.LoanClearingLogStat;
import com.abssqr.plat.common.facade.enums.TaskStatusEnum;
import com.abssqr.plat.common.facade.enums.TransCodeEnum;
import com.abssqr.plat.common.facade.model.plan.PlanCapitalLog;
import com.abssqr.plat.common.facade.model.trans.PlanClearingOrder;
import com.abssqr.plat.common.model.seq.SequenceUtil;
import com.general.system.common.model.Money;
import com.general.system.common.util.MessageUtil;
import com.general.system.tool.util.ToolUtil;
import com.google.common.collect.Lists;

import java.util.List;

/**
 *
 * @author hanfei
 * @version $Id: PlanClearingOrderConvert.java, v 0.1 2019-07-11 10:38 PM hanfei Exp $ 
 */
public class PlanClearingOrderConvert {
    
    public static PlanClearingOrder convert2Domain(LoanClearingLogStat statRes, String execTms) {
        if (ToolUtil.isEmpty(statRes)){
            return null;
        }
        PlanClearingOrder result = new PlanClearingOrder();
        result.setSeqNo(SequenceUtil.genSeqNo(statRes.getTransCode()));
        result.setTransCode(TransCodeEnum.getByCode(statRes.getTransCode()));
        result.setTransAmt(statRes.getAmt());
        result.setPlanNo(statRes.getPlanNo());
        result.setExecTms(execTms);
        result.setCntPtyCode(statRes.getCntPtyCode());
        result.setTransStatus(TaskStatusEnum.INIT);
        result.setAccountDate(statRes.getAccountDate());
        result.setLogMinMaxId(MessageUtil.formatMsg("{0}-{1}", statRes.getMinId(), statRes.getMaxId()));
        return result;
    }
    
    public static PlanClearingOrder buildClearingOrder(PlanCapitalLog capitalLog, String execTms) {
        PlanClearingOrder result = new PlanClearingOrder();
        result.setSeqNo(capitalLog.getSeqNo());
        result.setTransCode(capitalLog.getTransType().getTransCode());
        result.setTransAmt(capitalLog.getAmt());
        result.setPlanNo(capitalLog.getCntPtyCode());
        result.setExecTms(execTms);
        result.setCntPtyCode(capitalLog.getCntPtyCode());
        result.setTransStatus(TaskStatusEnum.INIT);
        result.setAccountDate(capitalLog.getAccountDate());
        result.setLogMinMaxId("");
        result.setMemo(MessageUtil.formatMsg("[{0}]-[{1}]-[{2}]回转放资金结算单",
                capitalLog.getSeqNo(),
                capitalLog.getTransType().getCode(),
                capitalLog.getTransType().getTransCode().getCode()));
        return result;
    }
    
    public static PlanClearingOrder convert2Domain(PlanClearingOrderDO param) {
        if (ToolUtil.isEmpty(param)){
            return null;
        }
        PlanClearingOrder result = new PlanClearingOrder();
        result.setId(param.getId());
        result.setTransAmt(Money.createWithCent(param.getTransAmt()));
        result.setSeqNo(param.getSeqNo());
        result.setPlanNo(param.getPlanNo());
        result.setExecTms(param.getExecTms());
        result.setTransCode(TransCodeEnum.getByCode(param.getTransCode()));
        result.setCntPtyCode(param.getCntPtyCode());
        result.setTransStatus(TaskStatusEnum.getByCode(param.getTransStatus()));
        result.setTransOrderNo(param.getTransOrderNo());
        result.setAccountDate(param.getAccountDate());
        result.setMemo(param.getMemo());
        result.setLogMinMaxId(param.getLogMinMaxId());
        return result;
    }
    
    public static List<PlanClearingOrderDO> convert2Dos(List<PlanClearingOrder> list) {
        if (ToolUtil.isEmpty(list)){
            return null;
        }
        List<PlanClearingOrderDO> result = Lists.newArrayList();
        list.forEach(one -> {
            result.add(convert2Do(one));
        });
        return result;
    }
    
    public static PlanClearingOrderDO convert2Do(PlanClearingOrder param) {
        if (ToolUtil.isEmpty(param)){
            return null;
        }
        PlanClearingOrderDO result = new PlanClearingOrderDO();
        result.setId(param.getId());
        result.setTransAmt(param.getTransAmt().getCent());
        result.setSeqNo(param.getSeqNo());
        result.setPlanNo(param.getPlanNo());
        result.setExecTms(param.getExecTms());
        result.setTransCode(param.getTransCode().getCode());
        result.setCntPtyCode(param.getCntPtyCode());
        result.setTransStatus(param.getTransStatus().getCode());
        result.setTransOrderNo(param.getTransOrderNo());
        result.setAccountDate(param.getAccountDate());
        result.setMemo(param.getMemo());
        result.setLogMinMaxId(param.getLogMinMaxId());
        return result;
    }
    
//    /**
//     * 变更 ClearingOrder的 交易金额与预留金额
//     * 如果有预留金额 则将金额扣除 针对放款池计划 回转放场景会对冻结金额进行预留
//     * @param ast
//     * @param order
//     */
//    public static void calcRetainAmt(PlanAst ast, PlanClearingOrder order) {
//        // 计算预留余额差值
//        Money amt = order.getTransAmt().subtract(ast.retainBalAmt());
//        if (amt.isNegtive()){
//            order.setRetainAmt(order.getTransAmt());
//            order.setTransAmt(new Money());
//        }else{
//            order.setRetainAmt(ast.retainBalAmt());
//            order.setTransAmt(amt);
//        }
//    }
}
