/**
 * abssqr.com Inc.
 * Copyright (c) 2017-2019 All Rights Reserved.
 */
package com.abssqr.plat.common.model.convertor;

import com.abssqr.plat.common.dal.mysql.auto.dataobject.PlanInvestStructureDO;
import com.abssqr.plat.common.facade.enums.IntrTypeEnum;
import com.abssqr.plat.common.facade.enums.LayerTypeEnu;
import com.abssqr.plat.common.facade.model.plan.InvestStructure;
import com.abssqr.plat.common.facade.result.plan.PlanInvestStructureVO;
import com.abssqr.plat.common.model.enums.IdTypeEnum;
import com.abssqr.plat.common.model.seq.SequenceUtil;
import com.general.system.common.model.Money;
import com.google.common.collect.Lists;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;

import java.math.BigDecimal;
import java.util.List;

/**
 * @author bangis.wangdf
 * @version com.abssqr.plat.common.model.convertor: PlanInvestStructureConvert.java, v 0.1 2019-05-31 21:29 bangis.wangdf Exp $
 */
public class PlanInvestStructureConvert {
    public static List<InvestStructure> convert2InvestStructureDomainList(
            List<PlanInvestStructureDO> investStructureDOS) {
        List<InvestStructure> result = Lists.newArrayList();
        if (CollectionUtils.isNotEmpty(investStructureDOS)) {
            investStructureDOS.forEach(planInvestStructureDO -> {
                result.add(convert2InvestStructureDomain(planInvestStructureDO));
            });
        }
        return result;
    }

    public static InvestStructure convert2InvestStructureDomain(PlanInvestStructureDO param) {
        if (param == null) {
            return null;
        }
        InvestStructure result = new InvestStructure();
        //layerAmt 层级规模
        result.setLayerAmt(Money.createWithCent(param.getLayerAmt()));
        //layerNo 编号
        result.setLayerNo(param.getLayerNo());
        //intrType 利率类型
        result.setIntrType(IntrTypeEnum.getByCode(param.getIntrType()));
        //layerName 层次名称
        result.setLayerName(param.getLayerName());
        //layerType 层级类型
        result.setLayerType(LayerTypeEnu.getByCode(param.getLayerType()));
        //layerEndDate 到期日
        result.setLayerEndDate(param.getLayerEndDate());
        //layerIntr 层级利率
        result.setLayerIntr(param.getLayerIntr());
        // 起息日
        result.setEffectDate(param.getEffectDate());
        return result;
    }

    private static PlanInvestStructureDO convert2Do(String planNo, InvestStructure param) {
        PlanInvestStructureDO result = new PlanInvestStructureDO();

        //layerAmt 层级规模
        result.setLayerAmt(param.getLayerAmt().getCent());
        //planNo 计划编号
        result.setPlanNo(planNo);
        //layerNo 编号
        result.setLayerNo(param.getLayerNo());
        if (StringUtils.isBlank(result.getLayerNo())) {
            result.setLayerNo(SequenceUtil.genId(IdTypeEnum.INVESTSTRUCTURE));
        }
        //intrType 利率类型
        if (param.getLayerIntr() == null) {
            param.setLayerIntr(BigDecimal.ZERO);
        }
        if (BigDecimal.ZERO.compareTo(param.getLayerIntr()) == 0) {
            param.setIntrType(IntrTypeEnum.NOTICKET);
        }
        result.setIntrType(param.getIntrType().getCode());
        //layerName 层次名称
        result.setLayerName(param.getLayerName());
        //layerType 层级类型
        result.setLayerType(param.getLayerType().getCode());
        //layerEndDate 到期日
        result.setLayerEndDate(param.getLayerEndDate());
        //layerIntr 层级利率
        result.setLayerIntr(param.getLayerIntr());
        // 起息日
        result.setEffectDate(param.getEffectDate());
        return result;
    }

    public static List<PlanInvestStructureDO> convert2Dos(String planNo, List<InvestStructure> investStructures) {
        if (CollectionUtils.isEmpty(investStructures)) {
            return null;
        }
        List<PlanInvestStructureDO> result = Lists.newArrayList();
        investStructures.forEach(param -> {
            result.add(convert2Do(planNo, param));
        });
        return result;
    }

    public static PlanInvestStructureVO convert2Vo(InvestStructure param) {

        if (null == param) {
            return null;
        }
        PlanInvestStructureVO result = new PlanInvestStructureVO();
        result.setLayerNo(param.getLayerNo());
        result.setLayerName(param.getLayerName());
        return result;
    }

    public static List<PlanInvestStructureVO> convert2VoList(List<InvestStructure> param) {
        List<PlanInvestStructureVO> result = Lists.newArrayList();
        param.forEach(item->{
            result.add(convert2Vo(item));
        });
        return result;
    }
}
