/**
 * abssqr.com Inc. 
 * Copyright (c) 2017-2019 All Rights Reserved. 
 */
package com.abssqr.plat.common.model.domain.ast;

import com.abssqr.plat.common.facade.enums.DebtMoneyFieldEnum;
import com.abssqr.plat.common.facade.enums.ProfitTypeEnum;
import com.abssqr.plat.common.model.domain.loanTrans.LoanAstProfitTransDetail;
import com.abssqr.plat.common.model.domain.loanTrans.LoanInstalTransDetail;
import com.general.system.common.model.Money;
import com.general.system.common.util.VarChecker;

import java.util.List;

/**
 *
 * @author zhenxuan.luo
 * @version com.abssqr.plat.core.service.profit.entity: LoanAstMeasure.java, v 0.1 2019-11-18 上午01:11 zhenxuan.luo Exp $ 
 */
public class LoanAstMeasure extends ProfitMeasure {
    private LoanAst loanAst;
    
    private int srcTerm;
    
    /**
     * 通过机构资产收益构造
     *
     * @param loanAst
     */
    public static LoanAstMeasure buildByLoanAst(LoanAst loanAst, int srcTerm, Money loanAstPrinAmt) {
        LoanAstMeasure astProfitMeasure = new LoanAstMeasure();
        astProfitMeasure.srcTerm = srcTerm;
        astProfitMeasure.loanAst = loanAst;
        LoanAstProfit loanAstProfit = loanAst.getLoanAstProfit(srcTerm, ProfitTypeEnum.OWN);
        VarChecker.checkNotNull(loanAstProfit, "机构资产[{0}-src：{1}]持有资产收益不能为空", loanAst.getLoanAstNo(), srcTerm);
        
        astProfitMeasure.intrEntry = new AstProfitUnit(DebtMoneyFieldEnum.INTR, loanAst.getPrinBal(),
                loanAstProfit.getEntryAmt().getByFieldType(DebtMoneyFieldEnum.INTR), loanAstProfit.getIntrEntryDec());
        
        if (srcTerm == loanAst.getTermNo()) {
            // 本罚只分配给当期
            astProfitMeasure.prinPenalEntry = new AstProfitUnit(DebtMoneyFieldEnum.PRIN_ODUE_PNY, loanAst.getPrinBal(),
                    loanAstProfit.getEntryAmt().getByFieldType(DebtMoneyFieldEnum.PRIN_ODUE_PNY),
                    loanAstProfit.getPrinPenalEntryDec());
        }
        
        astProfitMeasure.intrPenalEntry = new AstProfitUnit(DebtMoneyFieldEnum.INTR_ODUE_PNY,
                loanAstProfit.getBal().getByFieldType(DebtMoneyFieldEnum.INTR),
                loanAstProfit.getEntryAmt().getByFieldType(DebtMoneyFieldEnum.INTR_ODUE_PNY),
                loanAstProfit.getIntrPenalEntryDec());
        
        astProfitMeasure.feeEntry = new AstProfitUnit(DebtMoneyFieldEnum.FEE, loanAst.getPrinBal(),
                loanAstProfit.getEntryAmt().getByFieldType(DebtMoneyFieldEnum.FEE), loanAstProfit.getFeeEntryDec());
        
        astProfitMeasure.feePenalEntry = new AstProfitUnit(DebtMoneyFieldEnum.FEE_PNY,
                loanAstProfit.getBal().getByFieldType(DebtMoneyFieldEnum.FEE),
                loanAstProfit.getEntryAmt().getByFieldType(DebtMoneyFieldEnum.FEE_PNY),
                loanAstProfit.getFeePenalEntryDec());
        
        if (loanAstPrinAmt == null) {
            loanAstPrinAmt = new Money();
        }
        astProfitMeasure.otherFeeEntry = new AstProfitUnit(DebtMoneyFieldEnum.OTHER_FEE, loanAstPrinAmt,
                loanAstProfit.getEntryAmt().getByFieldType(DebtMoneyFieldEnum.OTHER_FEE),
                loanAstProfit.getOtherFeeEntryDec());
        
        LoanAstProfit splitAstProfit = loanAst.getLoanAstProfit(srcTerm, ProfitTypeEnum.SPLIT);
        if (null != splitAstProfit) {
            astProfitMeasure.intrPenalEntry.getBase()
                    .addTo(splitAstProfit.getBal().getByFieldType(DebtMoneyFieldEnum.INTR));
            astProfitMeasure.feePenalEntry.getBase()
                    .addTo(splitAstProfit.getBal().getByFieldType(DebtMoneyFieldEnum.FEE));
        }
        
        return astProfitMeasure;
    }
    
    public List<LoanAstProfitTransDetail> settle(LoanInstalTransDetail instalTransDetail, String memo) {
        LoanAstProfitGroup profitGroup = loanAst.getLoanAstProfitGrp(srcTerm);
        // 在构造LoanAstMeasure时应该已经初始化了LoanAstProfit
        //        if (null == profitGroup) {
        //            LoanAstProfit ownAstProfit = LoanAstUtil.buildDefaultProfit(instalTransDetail.getLoanInstal(), loanAst,
        //                    instalTransDetail.getActiveLog().getAccountDate());
        //            // 暂时只支持利息分润的模式
        //            if (loanAst.getAstPriceType() == PriceTypeEnum.SPLIT_PROFIT) {
        //                ownAstProfit.setSplitRate(loanAst.getAstPrice());
        //                // 默认将超额收益留在放款机构，固定逻辑，后面需要变更再说
        //                ownAstProfit.setSplitOrgCode(loanAst.getLenderOrgCode());
        //            }
        //            loanAst.addLoanAstProfit(ownAstProfit);
        //        }
        List<LoanAstProfitTransDetail> ret = profitGroup.settle(this, instalTransDetail, memo);
        return ret;
    }
    
    public LoanAst getLoanAst() {
        return loanAst;
    }
    
    public int getSrcTerm() {
        return srcTerm;
    }
}