/**
 * abssqr.com Inc. 
 * Copyright (c) 2017-2019 All Rights Reserved. 
 */
package com.abssqr.plat.common.model.domain.loanTrans;

import com.abssqr.plat.common.facade.enums.EventCodeEnum;
import com.abssqr.plat.common.facade.enums.LoanAstStatusEnum;
import com.abssqr.plat.common.facade.enums.TransCodeEnum;
import com.abssqr.plat.common.model.domain.ast.Loan;
import com.abssqr.plat.common.model.domain.ast.LoanAst;
import com.abssqr.plat.common.model.seq.SequenceUtil;
import com.general.system.common.model.Money;
import com.general.system.common.util.DateTimeUtil;

import java.util.Date;

/**
 *
 * @author zhenxuan.luo
 * @version com.abssqr.plat.common.model.domain.loanTrans: LoanAstTransDetail.java, v 0.1 2019-11-13 下午14:10 zhenxuan.luo Exp $ 
 */
public class LoanAstTransDetail implements ITransDtl {
    
    /**
     * 机构资产
     */
    private LoanAst               loanAst;
    /**
     * 机构资产流水
     */
    private LoanAstLog            activeLog;
    /**
     *
     */
    private boolean               isUpdate = false;
    
    private LoanAstTransDetail() {
    }
    
    /**
     * 构建
     *
     * @param loanAst
     * @param loanInstalTransDetail
     * @return
     */
    public static LoanAstTransDetail createTransDtl(LoanAst loanAst,
                                                    LoanInstalTransDetail loanInstalTransDetail,
                                                    EventCodeEnum eventCode) {
        
        // 1. 构造资产交易明细
        LoanAstTransDetail transDetail = new LoanAstTransDetail();
        
        // 2. 构造交易流水
        LoanAstLog log = buildLog(loanAst, loanInstalTransDetail, eventCode);
        
        transDetail.loanAst = loanAst;
        transDetail.activeLog = log;
        
        if (loanAst.isNew()) {
            transDetail.isUpdate = true;
        }
        
        loanInstalTransDetail.getLoanAstTransDetails().add(transDetail);
        return transDetail;
    }
    
    private static LoanAstLog buildLog(LoanAst loanAst, LoanInstalTransDetail loanInstalTransDetail,
                                       EventCodeEnum eventCode) {
        
        LoanInstalLog loanInstalLog = loanInstalTransDetail.getActiveLog();
        Loan loan = loanInstalTransDetail.getLoanTransDetail().getLoan();
    
        LoanAstLog log = new LoanAstLog();
        log.setAstNo(loanAst.getAstNo());
        log.setOwnOrg(loanAst.getOwnOrg());
        log.setProdNo(loanAst.getProdNo());
        log.setUserId(loanAst.getUserId());
        log.setInAstNo(loanAst.getInAstNo());
        log.setOwnPack(loanAst.getOwnPack());
        log.setOutAstNo(loanAst.getOutAstNo());
        log.setLoanAstNo(loanAst.getLoanAstNo());
        log.setOutProdNo(loanAst.getOutProdNo());
        log.setLenderOrgCode(loanAst.getLenderOrgCode());
        log.setTermNo(loanAst.getTermNo());
        
        log.setSeqNo(SequenceUtil.genSeqByLoan(loan, eventCode.getSceneCode()));
        log.setBizNo(loanInstalLog.getBizNo());
        log.setOutBizNo(loanInstalLog.getOutBizNo());
        log.setExecTms(loanInstalLog.getExecTms());
        log.setTransTime(loanInstalLog.getTransTime());
        log.setAccountDate(loanInstalLog.getAccountDate());
        log.setEventCode(eventCode);
        
        log.setBfAstStatus(loanAst.getAstStatus());
        return log;
        
    }
    
    public void transferOut() {
        this.setUpdate(true);
        
        activeLog.setPrinAmt(loanAst.getPrinBal().clone());
        loanAst.setPrinBal(new Money());
        
        this.clearLoanAst(this.activeLog.getAccountDate(), this.activeLog.getEventCode(), LoanAstStatusEnum.OUT);
    }
    
    public void transIn(Money prin, Money cost) {
        this.setUpdate(true);
        
        activeLog.setPrinAmt(prin.clone());
        activeLog.setClrgAmt(cost.clone());
        
        loanAst.setPrinBal(loanAst.getPrinBal().add(prin));
        loanAst.setCostAmt(loanAst.getCostAmt().add(cost));
        loanAst.setAstStatus(LoanAstStatusEnum.NORMAL);
    }
    
    public void processTransAmt(Money transAmt) {
        if (transAmt.isZero()) {
            return;
        }
        isUpdate = true;
        Money curBal = this.loanAst.getPrinBal();
        
        this.activeLog.getPrinAmt().addTo(transAmt);
        // 1. 根据事件码，设定符号
        int sign = this.activeLog.getEventCode().getAssetFlow().getSign();
        
        // 2. 计算交易后余额
        Money newBal = curBal.add(transAmt.multiply(sign));
        
        if (this.activeLog.getEventCode().getSceneCode() == TransCodeEnum.REPO) {
            this.loanAst.getPaidPrinAmt().addTo(transAmt);
        }else if (this.activeLog.getEventCode() == EventCodeEnum.ADJ_TERM_OUT) {
            this.loanAst.getCostAmt().subtractFrom(transAmt);
        } else if (this.activeLog.getEventCode() == EventCodeEnum.ADJ_TERM_IN) {
            this.loanAst.getCostAmt().addTo(transAmt);
        }
        
        // 3. 回填余额
        this.loanAst.setPrinBal(newBal);
    }
    
    public void processTransAmtOnly(Money transAmt) {
        isUpdate = true;
        this.activeLog.getPrinAmt().addTo(transAmt);
    }
    
    public void processPaidAmtOnly(Money transAmt) {
        isUpdate = true;
        this.loanAst.getPaidPrinAmt().addTo(transAmt);
    }
    
    public LoanAst getLoanAst() {
        return loanAst;
    }
    
    public LoanAstLog getActiveLog() {
        return activeLog;
    }
    
    public boolean isUpdate() {
        return isUpdate;
    }
    
    public void setUpdate(boolean update) {
        isUpdate = update;
    }
    
    public void clearLoanAst(Date accountDate, EventCodeEnum eventCode, LoanAstStatusEnum astStatus) {
        this.setUpdate(true);
        this.loanAst.setClearDate(accountDate);
        this.loanAst.setClearEvnt(eventCode);
        this.loanAst.setAstStatus(astStatus);
    }
    
    @Override
    public void processBeforeUpdate() {
        activeLog.setAfPrinBal(loanAst.getPrinBal().clone());
        activeLog.setAfAstStatus(loanAst.getAstStatus());
        
        if (isUpdate) {
            // 3. 处理初笔交易
            if (DateTimeUtil.isBeforeOnDate(loanAst.getLastUpdateDate(), this.getActiveLog().getAccountDate())) {
                loanAst.setLastUpdateDate(this.getActiveLog().getAccountDate());
            }
        }
    }
}