/**
 * abssqr.com Inc. 
 * Copyright (c) 2017-2019 All Rights Reserved. 
 */
package com.abssqr.plat.common.model.repo.plan.impl;

import com.abssqr.plat.common.dal.mysql.auto.dao.PlanAcctTitleDAO;
import com.abssqr.plat.common.dal.mysql.auto.dataobject.PlanAcctTitleDO;
import com.abssqr.plat.common.facade.enums.TitleTypeEnum;
import com.abssqr.plat.common.facade.model.plan.PlanAcctTitle;
import com.abssqr.plat.common.model.convertor.PlanAcctTitleConvertor;
import com.abssqr.plat.common.model.repo.plan.PlanAcctTitleRepo;
import com.general.system.common.util.VarChecker;
import com.google.common.collect.Lists;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.util.CollectionUtils;

import java.util.List;
import java.util.stream.Collectors;

/**
 *
 * @author zhenxuan.luo
 * @version com.abssqr.plat.common.model.repo.plan.impl: PlanAccountTitleRepoImpl.java, v 0.1 2019-05-31 17:48 zhenxuan.luo Exp $
 */
@Component
public class PlanAcctTitleRepoImpl implements PlanAcctTitleRepo {
    
    @Autowired
    private PlanAcctTitleDAO planAcctTitleDAO;
    
    @Override
    public int insert(PlanAcctTitle entity) {
        if (entity == null) {
            return 0;
        }
        
        return planAcctTitleDAO.insert(PlanAcctTitleConvertor.convert2DO(entity));
    }
    
    @Override
    public int insertBatch(List<PlanAcctTitle> list) {
        
        if (CollectionUtils.isEmpty(list)) {
            return 0;
        }
        
        List<PlanAcctTitleDO> acctTitleDOS = Lists.newArrayList();
        
        for (PlanAcctTitle planAccountTitle : list) {
            acctTitleDOS.add(PlanAcctTitleConvertor.convert2DO(planAccountTitle));
        }
        return planAcctTitleDAO.insertBatch(acctTitleDOS);
    }
    
    @Override
    public int updateAmt(PlanAcctTitle entity) {
        if (null == entity) {
            return 0;
        }
        return planAcctTitleDAO.updateAmt(PlanAcctTitleConvertor.convert2DO(entity));
    }
    
    @Override
    public List<PlanAcctTitle> getByEntityNo(String planNo) {
        List<PlanAcctTitle> res = Lists.newArrayList();
        
        List<PlanAcctTitleDO> doList = planAcctTitleDAO.getByPlan(planNo);
        for (PlanAcctTitleDO planAcctTitleDO : doList) {
            res.add(PlanAcctTitleConvertor.convert2Domain(planAcctTitleDO));
        }
        return res;
    }
    
    @Override
    public PlanAcctTitle getByTitleNo(String planNo, String titleNo) {
        return PlanAcctTitleConvertor.convert2Domain(planAcctTitleDAO.getByTitleNo(planNo, titleNo));
    }

    /**
     * 根据计划查询列表
     *
     * @param planNo
     * @param titleTypeEnums
     * @return
     */
    @Override
    public List<PlanAcctTitle> getTitleNames(String planNo, List<TitleTypeEnum> titleTypeEnums) {
        List<PlanAcctTitle> res = Lists.newArrayList();
        List<String> collect = titleTypeEnums.stream().map(TitleTypeEnum::getCode).collect(Collectors.toList());
        List<PlanAcctTitleDO> doList = planAcctTitleDAO.getByPlanAndTypes(planNo,collect);
        for (PlanAcctTitleDO planAcctTitleDO : doList) {
            res.add(PlanAcctTitleConvertor.convert2Domain(planAcctTitleDO));
        }
        return res;
    }

    @Override
    public List<PlanAcctTitle> getAcctFinFeeTitles(List<String> planNos) {
        List<PlanAcctTitle> res = Lists.newArrayList();
        List<PlanAcctTitleDO> doList = planAcctTitleDAO.getFinFeesByPlan(planNos);
        for (PlanAcctTitleDO planAcctTitleDO : doList) {
            res.add(PlanAcctTitleConvertor.convert2Domain(planAcctTitleDO));
        }
        return res;
    }


    @Override
    public int cleanByPlanNo(String planNo){
        VarChecker.checkNotNull(planNo);
        return planAcctTitleDAO.deleteByPlanNo(planNo);
    }
}