/**
 * abssqr.com Inc.
 * Copyright (c) 2017-2018 All Rights Reserved.
 */
package com.abssqr.plat.common.model.repo.plan.impl;

import com.abssqr.plat.common.dal.mysql.auto.dao.OrganizationEntityDAO;
import com.abssqr.plat.common.dal.mysql.auto.dao.PlanDAO;
import com.abssqr.plat.common.dal.mysql.auto.dao.PlanTranScreenRelDAO;
import com.abssqr.plat.common.dal.mysql.auto.dataobject.OrganizationEntityDO;
import com.abssqr.plat.common.dal.mysql.auto.dataobject.PlanDO;
import com.abssqr.plat.common.dal.mysql.auto.paging.PlanListPage;
import com.abssqr.plat.common.facade.enums.PlanStatusEnum;
import com.abssqr.plat.common.facade.enums.PlanTypeEnum;
import com.abssqr.plat.common.facade.enums.PriceTypeEnum;
import com.abssqr.plat.common.facade.enums.YNEnum;
import com.abssqr.plat.common.facade.model.org.OrganizationEntity;
import com.abssqr.plat.common.facade.model.plan.PlanBase;
import com.abssqr.plat.common.facade.model.prod.LoanProduct;
import com.abssqr.plat.common.model.convertor.PlanConvert;
import com.abssqr.plat.common.model.repo.plan.PlanRepo;
import com.abssqr.plat.common.model.repo.prod.LoanProdRepository;
import com.abssqr.plat.common.model.utils.TextUtil;
import com.general.system.bpm.enums.ApproveStatusEnum;
import com.general.system.common.util.VarChecker;
import com.general.system.tool.util.ToolUtil;
import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import com.google.common.collect.Sets;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Repository;

import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.stream.Collectors;

/**
 * @author bangis.wangdf
 * @version com.abssqr.plat.common.model.repo.plan: PlanRepositoryImpl.java, v 0.1 2018-01-04 16:06 hongwei.wang Exp $
 */
@Repository
public class PlanRepoImpl implements PlanRepo {
    @Autowired
    PlanDAO planDAO;
    @Autowired
    OrganizationEntityDAO organizationEntityDAO;
    @Autowired
    PlanTranScreenRelDAO planTranScreenRelDAO;
    @Autowired
    LoanProdRepository loanProdRepository;

    /**
     * 分页查询获取计划列表
     *
     * @param planList
     * @return
     */
    @Override
    public PlanListPage getPlanList(PlanListPage planList) {
        return planDAO.getPlanList(planList);
    }

    /**
     * 计划是否存在
     *
     * @param planNo
     * @return
     */
    @Override
    public Integer planExist(String planNo, String planName) {
        return planDAO.planExist(planNo, planName);
    }

    @Override
    public Integer getSamePlan(String planNo, String planName) {
        return planDAO.getSamePlan(planNo, planName);
    }

    /**
     * 新增计划
     *
     * @param plan
     * @return
     */
    @Override
    public void addPlan(PlanBase plan) {
        PlanDO planDO = PlanConvert.convert2Do(plan);
        planDAO.insert(planDO);
        if (plan.getPlanType() == PlanTypeEnum.SPV && plan instanceof OrganizationEntity) {
            OrganizationEntityDO entityDO = convert2EntityDO((OrganizationEntity) plan);
            organizationEntityDAO.insert(entityDO);
        }
    }

    /**
     * 修改计划
     *
     * @param plan
     */
    @Override
    public void updatePlan(PlanBase plan) {
        PlanDO planDO = PlanConvert.convert2Do(plan);
        planDAO.updateByPlanNo(planDO);
        if (plan.getPlanType() == PlanTypeEnum.SPV && plan instanceof OrganizationEntity) {
            OrganizationEntityDO entityDO = convert2EntityDO((OrganizationEntity) plan);
            organizationEntityDAO.updateByEntityCode(entityDO);
        }

    }

    @Override
    public void updateStatusByPlanNo(String planNo, String gmtModifier, ApproveStatusEnum approveStatus) {
        String approveStatusCode = approveStatus == null ? null : approveStatus.getCode();
        planDAO.updateStatusByPlanNo(planNo, null, gmtModifier, approveStatusCode);
    }

    @Override
    public void updateStatus(String planNo, PlanStatusEnum status, ApproveStatusEnum approveStatus) {
        String statusCode = status == null ? null : status.getCode();
        String approveStatusCode = approveStatus == null ? null : approveStatus.getCode();
        planDAO.updateStatusByPlanNo(planNo, statusCode, null, approveStatusCode);
    }

    @Override
    public void updatePassed(String planNo, Boolean passed) {
        planDAO.updatePassed(planNo, passed);
    }

    @Override
    public PlanBase getPlanByNo(String planNo) {
        PlanDO planDO = planDAO.getByPlanNo(planNo);
        PlanBase planBase = PlanConvert.convert2Domain(planDO);
        fullEntity(planNo, planBase);
        return planBase;
    }

    @Override
    public PlanBase lockPlanByNo(String planNo) {
        PlanDO planDO = planDAO.lockByPlanNo(planNo);
        PlanBase planBase = PlanConvert.convert2Domain(planDO);
        fullEntity(planNo, planBase);
        return planBase;
    }

    @Override
    public <T extends PlanBase> List<T> getPlanByPlanNos(List<String> planNos, PlanTypeEnum planType,
                                                         PlanStatusEnum status) {
        return getPlanByPlanNos(planNos, planType, Lists.newArrayList(status));
    }

    @Override
    public <T extends PlanBase> List<T> getPlanByPlanNos(List<String> planNos, PlanTypeEnum planType,
                                                         List<PlanStatusEnum> statusList) {
        VarChecker.checkNotEmpty(statusList);
        List<String> actTypes = statusList.stream().map(PlanStatusEnum::getCode).collect(Collectors.toList());
        List<PlanDO> planDOS = planDAO.getPlansByStatusList(planType == null ? null : planType.getCode(), planNos,
                actTypes);
        return this.listPlanDO2Base(planDOS);
    }

    /**
     * 获取所有存续期的计划
     *
     * @return
     */
    @Override
    public <T extends PlanBase> List<T> getPlansByStatus(PlanTypeEnum planType, PlanStatusEnum status) {
        return this.getPlansByStatusList(planType, Lists.newArrayList(status));
    }

    /**
     * 获取所有存续期的计划
     *
     * @return
     */
    @Override
    public <T extends PlanBase> List<T> getPlansByStatusList(PlanTypeEnum planType, List<PlanStatusEnum> statusList) {
        return getPlanByPlanNos(null, planType, statusList);
    }

    @Override
    public Long getAllPlanAmt(PlanTypeEnum planType, PlanStatusEnum planStatusEnum) {
        return planDAO.getAllPlanAmt(planStatusEnum.getCode(), planType.getCode());
    }

    @Override
    public Map<String, String> getPlanNames(List<String> planNos) {
        return planDAO.queryByPlanNo(planNos);
    }

    @Override
    public Map<String, List<String>> getPlanBySpvs(List<String> ownOrgs) {
        Map<String, List<String>> result = Maps.newHashMap();
        if (ToolUtil.isEmpty(ownOrgs)) {
            return result;
        }
        List<OrganizationEntityDO> entityDOS = organizationEntityDAO.getByEntityCodesList(ownOrgs);
        if (CollectionUtils.isNotEmpty(entityDOS)) {
            Map<String, List<String>> prodsMap = Maps.newHashMap();
            Set<String> prodSet = Sets.newHashSet();
            entityDOS.forEach(organizationEntityDO -> {
                String prodLst = organizationEntityDO.getProdLst();
                List<String> prods = TextUtil.convertTxt2List(prodLst);
                prodSet.addAll(prods);
                prodsMap.put(organizationEntityDO.getEntityCode(), prods);
            });
            Map<String, List<String>> planNoMap = planTranScreenRelDAO.getPlanNosByProdList(
                    Lists.newArrayList(prodSet));
            prodsMap.forEach((ownOrg, prods) -> {
                planNoMap.forEach((prodKey, palnVel) -> {
                    if (prods.contains(prodKey)) {
                        List<String> planNos = result.get(ownOrg);
                        if (planNos == null) {
                            planNos = Lists.newArrayList();
                            result.put(ownOrg, planNos);
                        }
                        planNos.addAll(palnVel);
                    }
                });
            });
        }

        return result;
    }

    @Override
    public List<String> getPlanNosBySpvNo(String spvPlanNo) {
        Map<String, List<String>> planBySpvs = getPlanBySpvs(Lists.newArrayList(spvPlanNo));
        return planBySpvs.getOrDefault(spvPlanNo, Lists.newArrayList());
    }

    @Override
    public List<OrganizationEntity> getSpvByManagerOrgCode(String managerOrgCode) {
        List<PlanDO> planDOS = planDAO.getSpvByManagerOrgCode(managerOrgCode);
        return listPlanDO2Base(planDOS);
    }

    @Override
    public Long getFailDailyCount(Date curDate) {
        return planDAO.getFailDailyCount(curDate);
    }

    @Override
    public Long updatePirceType(String planNo, PriceTypeEnum priceType) {
        String type = null;
        if (priceType != null) {
            type = priceType.getCode();
        }
        return Long.valueOf(planDAO.updatePriceType(planNo, type));
    }

    private <T extends PlanBase> List<T> listPlanDO2Base(List<PlanDO> planDOS) {
        List<T> planBases = Lists.newArrayList();
        if (ToolUtil.isEmpty(planDOS)) {
            return planBases;
        } else {
            List<String> planNos = planDOS.stream().map(PlanDO::getPlanNo).collect(Collectors.toList());
            Map<String, OrganizationEntityDO> entityDOMap = organizationEntityDAO.getByEntityCodes(planNos);
            for (PlanDO planDO : planDOS) {
                T planBase = PlanConvert.convert2Domain(planDO);
                if (planBase.getPlanType() == PlanTypeEnum.SPV && planBase instanceof OrganizationEntity) {
                    OrganizationEntityDO entityDO = entityDOMap.get(planBase.getPlanNo());
                    fullEntity((OrganizationEntity) planBase, entityDO);
                }
                planBases.add(planBase);
            }
        }
        return planBases;
    }

    private void fullEntity(String planNo, PlanBase planBase) {
        if (planBase.getPlanType() == PlanTypeEnum.SPV && planBase instanceof OrganizationEntity) {
            OrganizationEntity organizationEntity = (OrganizationEntity) planBase;
            OrganizationEntityDO entityDO = organizationEntityDAO.getByEntityCode(planNo);
            fullEntity(organizationEntity, entityDO);
        }
    }

    private void fullEntity(OrganizationEntity organizationEntity, OrganizationEntityDO entityDO) {
        if (entityDO != null) {
            organizationEntity.setProdCodeList(TextUtil.convertTxt2List(entityDO.getProdLst()));
            organizationEntity.setNeedAlloc(YNEnum.getByCode(entityDO.getNeedAlloc()));
            organizationEntity.setStopPayDate(entityDO.getStopPayDate());
            organizationEntity.setManagerOrgCode(entityDO.getManagerOrgCode());
        }
    }

    private OrganizationEntityDO convert2EntityDO(OrganizationEntity entity) {
        OrganizationEntityDO entityDO = new OrganizationEntityDO();
        entityDO.setProdLst(TextUtil.convertSet2Txt(Sets.newHashSet(entity.getProdCodeList())));
        entityDO.setStopPayDate(entity.getStopPayDate());
        entityDO.setNeedAlloc(entity.getNeedAlloc().getCode());
        entityDO.setEntityCode(entity.getPlanNo());
        entityDO.setManagerOrgCode(null);
        if (CollectionUtils.isNotEmpty(entity.getProdCodeList())) {
            List<LoanProduct> prods = loanProdRepository.getBybssqrProdCodes(entity.getProdCodeList());
            if (CollectionUtils.isNotEmpty(prods)) {
                entityDO.setManagerOrgCode(prods.stream().findFirst().get().getManagerOrgCode());
            }
        }
        return entityDO;
    }

    @Override
    public int deleteByPlanNo(String planNo) {
        VarChecker.checkNotNull(planNo);
        int result = planDAO.deleteByPlanNo(planNo);
        result += organizationEntityDAO.deleteByEntityCode(planNo);
        return result;
    }

    @Override
    public List<PlanBase> getAllPlanAstByType(String planType) {
        List<PlanBase> ret=new ArrayList<>();
        List<PlanDO> allPlanByType = planDAO.getAllPlanByType(planType);
        if(CollectionUtils.isNotEmpty(allPlanByType)){
           allPlanByType.forEach(v->{
               ret.add(PlanConvert.convert2Domain(v));
           });

        }
        return ret;
    }
    
    @Override
    public PlanBase getPlanByMapCache(Map<String, PlanBase> planMap, String planNo){
        if (ToolUtil.isEmpty(planMap)){
            planMap = new HashMap<>();
        }
        PlanBase planBase = planMap.get(planNo);
        if (ToolUtil.isEmpty(planBase)){
            // 查询对手机构
            planBase = this.getPlanByNo(planNo);
            planMap.put(planBase.getPlanNo(), planBase);
        }
        return planBase;
    }
}
