/**
 * abssqr.com Inc.
 * Copyright (c) 2017-2019 All Rights Reserved.
 */
package com.abssqr.plat.common.model.utils;

import com.jcraft.jsch.ChannelSftp;
import com.jcraft.jsch.JSch;
import com.jcraft.jsch.JSchException;
import com.jcraft.jsch.Session;

import java.io.IOException;
import java.net.SocketException;
import java.util.Properties;

/**
 * @author bangis.wangdf
 * @version com.loan.common.util.utils: SftpFileUtil.java, v 0.1 2019-10-07 17:49 bangis.wangdf Exp $
 */
public class SftpFileUtil {

    private Session     session = null;
    private ChannelSftp channel = null;

    /**
     * 连接sftp服务器
     *
     * @param serverIP 服务IP
     * @param port     端口
     * @param userName 用户名
     * @param password 密码
     * @throws SocketException SocketException
     * @throws IOException IOException
     * @throws JSchException JSchException
     */
    public SftpFileUtil(String serverIP, int port, String userName, String password) {
        JSch jsch = new JSch();
        try {
            // 根据用户名，主机ip，端口获取一个Session对象
            session = jsch.getSession(userName, serverIP, port);
            // 设置密码
            session.setPassword(password);
            // 为Session对象设置properties
            Properties config = new Properties();
            config.put("StrictHostKeyChecking", "no");
            session.setConfig(config);
            // 通过Session建立链接
            session.connect();
            // 打开SFTP通道
            channel = (ChannelSftp)session.openChannel("sftp");
            // 建立SFTP通道的连接
            channel.connect();
        } catch (Exception e) {
            throw new RuntimeException("SFTP 创建失败", e);
        }
    }

    public ChannelSftp getChannel() {
        return channel;
    }

    public void close() {
        channel.quit();
        if (channel != null) {
            channel.disconnect();
        }
        if (session != null) {
            session.disconnect();
        }
        System.out.println("close-sftp-close");
    }
    
}
